%%% Elhanan Helpman, Oleg Itskhoki, Marc-Andreas Muendler and Stephen J. Redding (2016): 
%%% "Trade and Inequality: From Theory to Estimantion," Review of Economic Studies, forthcoming

%%% MAIN CODE FOR GMM BOUNDS ESTRIMATION AND COUNTERFACTUALS
%%% (FOR COUNTERFACTUALS SEE BOTTOM PART OF THE CODE)
%%% Produces FigureS A3 AND 2 (PANELS A AND B) IN THE PAPER


clear all
close all
cd '/home/sjredding/himr-restud/matlab/brazil'
clc


%% LOAD DATA

yr=1994; 
data = csvread('/data/sjredding/himr-restud/condwtvfe/mincer/agg-tmincer-1994-fun.csv');

N = size(data,1);       % number of observations (firms)
I = data(:,9);          % export status (dummy for exporter)
H = log(data(:,10));    % log employment
W = data(:,8);          % log wage (8 for FIRM FE PSI and 4 for MEAN LOG WAGE)
X = [H W I];            % data matrix
    
    
%% MOMENTS

FrX   = mean(I);               % fraction of exporters
Hbar  = mean(H);               % mean log employment
Hbar0 = (1-I)'*H/sum(1-I);     % mean log employment of non-exporters
Hbar1 = I'*H/sum(I);           % mean log employment of exporters
Wbar  = mean(W);               % mean log wages
Wbar0 = (1-I)'*W/sum(1-I);     % mean log wage of non-exporters
Wbar1 = I'*W/sum(I);           % mean log wage of exporters
sH    = std(H);                % st. dev. log employment
sH0   = std(H(I==0));          % st. dev. log employment for non-exporters
sH1   = std(H(I==1));          % st. dev. log employment for exporters
sW    = std(W);                % st. dev. log wages
sW0   = std(W(I==0));          % st. dev. log wage for non-exporters
sW1   = std(W(I==1));          % st. dev. log wages for exporters
cHW   = corr(H,W);             % corr. log employmenty and log wages
cHW0  = corr(H(I==0),W(I==0)); % corr. log employmenty and log wages for non-exporters
cHW1  = corr(H(I==1),W(I==1)); % corr. log employmenty and log wages for exporters

% Regression of wages on employment and exporters status
bbhat = regress(W,[ones(size(H,1),1) H I]);
bhat = bbhat(2);               % employment wage premium



%% FIRST BLOCK OF GMM SYSTEM
% (see notation in the Appendix A.6 of the paper)

Phihat  = 1-FrX;
fhat    = norminv(1-FrX,0,1);
phihat  = normpdf(fhat,0,1);
lhat0   = phihat/Phihat;
lhat1   = phihat/(1-Phihat);
Lhat0   = lhat0*(lhat0+fhat);
Lhat1   = lhat1*(lhat1-fhat);


%% BOUNDS
% (see explanation of the procedure in the paper)

% varying mu_h and matching moments to recover other parameters
muhtmp = (-3:.001:5)';
sutmp = sH^2 - muhtmp.^2*Phihat*(1-Phihat) - 2*phihat*muhtmp .* (Hbar1-Hbar0-muhtmp)/(lhat1-lhat0);
muhtmp2 = muhtmp(sutmp>=0);
sutmp2 = sutmp(sutmp>=0);
rutmp = (Hbar1-Hbar0-muhtmp2)/(lhat1-lhat0)./sqrt(max(sutmp2,0));

muh = muhtmp2(abs(rutmp)<=1);
su = sqrt(sH^2 - muh.^2*Phihat*(1-Phihat) - 2*phihat*muh .* (Hbar1-Hbar0-muh)/(lhat1-lhat0));
ru = (Hbar1-Hbar0-muh)/(lhat1-lhat0)./su;

    
% varying mu_w and matching moments to recover other parameters
muwtmp = (-2:.001:4)';
swtmp = sW^2 - muwtmp.^2*Phihat*(1-Phihat) - 2*phihat*muwtmp .* (Wbar1-Wbar0-muwtmp)/(lhat1-lhat0);
muwtmp2 = muwtmp(swtmp>=0);
swtmp2 = swtmp(swtmp>=0);
rwtmp = (Wbar1-Wbar0-muwtmp2)/(lhat1-lhat0)./sqrt(max(swtmp2,0));

muw = muwtmp2(abs(rwtmp)<=1);
sw = sqrt(sW^2 - muw.^2*Phihat*(1-Phihat) - 2*phihat*muw .* (Wbar1-Wbar0-muw)/(lhat1-lhat0));
rw = (Wbar1-Wbar0-muw)/(lhat1-lhat0)./sw;



Nh = size(muh,1);
Nw = size(muw,1);
muhmin = muh(1);
muhmax = muh(end);
muwmin = muw(1);
muwmax = muw(end);




%% Recovering the identified set
DATA = [];
for muh0 = muhmin:.001:muhmax;

    su0 = sqrt(sH^2 - muh0.^2*Phihat*(1-Phihat) - 2*phihat*muh0 .* (Hbar1-Hbar0-muh0)/(lhat1-lhat0));
    ru0 = (Hbar1-Hbar0-muh0)/(lhat1-lhat0)./su0;
    
    z1 = (cHW*sH*sW - muh0*muw*Phihat*(1-Phihat) - (muh0*rw.*sw + muw*ru0*su0 )*phihat )/su0^2;
    z2 = bhat*(1-ru0^2) + ru0*rw.*sw/su0;
    z3 = muw/muh0;
    z4 = (muw/muh0*su0^2 - sw.^2)/su0^2./(1-muw/muh0);

    % solving for mu_w given mu_h
    [fit0, ind0] = min((z1-z2).^2);
    muw0 = muw(ind0);
    rw0 = rw(ind0);
    sw0 = sw(ind0);
    
    [fitc, indc] = min((z1-z3).^2);
    muwc = muw(indc);
    
    betaimpl = (z1(indc)*su0^2-ru0*su0*rw(indc)*sw(indc))/su0^2/(1-ru0^2);
    
    pix = (muw0 - bhat*muh0) + (lhat1 + lhat0)*(rw0*sw0 - bhat*ru0*su0 );
    Rw2 = ( (2*z2(ind0)-bhat)*bhat*su0^2 + Phihat*(1-Phihat)*(bhat*muh0+pix)*(2*muw0-bhat*muh0-pix) ...
        + 2*phihat*( bhat*(muw0-bhat*muh0-pix)*ru0*su0 + (bhat*muh0+pix)*rw0*sw0 ) ) ...
        / ( sw0^2 + Phihat*(1-Phihat)*muw0^2 + 2*phihat*muw0*rw0*sw0 ) ;
    

    DATA = [DATA; [muh0  ru0 muw0 rw(ind0) z1(ind0) fit0 muwc rw(indc) z1(indc) fitc betaimpl pix Rw2 su0 sw0]];

end

MUH = DATA(:,1);
MUW = DATA(:,3);
RU0 = DATA(:,2);
RW0 = DATA(:,4);
RWC = DATA(:,8);
PIX = DATA(:,12);
RW2 = DATA(:,13);

SU0 = DATA(:,14);
SW0 = DATA(:,15);
ZT0 = DATA(:,5);
SV0 = sqrt(SW0.^2 - ZT0.^2.*SU0.^2);
RV0 = (RW0.*SW0 - ZT0.*SU0.*RU0)./SV0;
CONSTR = RW0.*SW0 + RU0.*SU0;



%% Plotting the GMM identified set (Figure A3)

figure(23)
plot(MUH,[MUW RU0 RV0],'linewidth',2)
hold on
plot(MUH,RW0,'r--','linewidth',1)
plot(MUH,CONSTR,'k--','linewidth',1)
plot([0 3],[0 0],'k:','linewidth',2)
xlim([muhmin,2.046])
ylim([-0.1,1])
set(gca,'FontSize',14)
set(gca,'xtick',[.25:.25:2])
set(gca,'ytick',[-.1 0:.2:1.2])
xlabel('$\mu_h$','FontSize',18,'interpreter','latex')
text(.7,.28,'$\mu_w$','FontSize',18,'interpreter','latex')
text(1.2,-.04,'$\rho_v$','FontSize',18,'interpreter','latex')
text(.85,.62,'$\rho_u$','FontSize',18,'interpreter','latex')
text(1,.17,'$\rho_\omega$','FontSize',18,'interpreter','latex')
text(1,.72,'$(1\!+\!\zeta)\rho_u \sigma_u + \rho_v \sigma_v$','FontSize',16,'interpreter','latex')

print -depsc idset.eps


%% FROM THIS THE UPPER BOUND OF THE GMM ID SET IS 2.046 -- USED THROUGHOUT BELOW


%% AUTARKY COUNTERFACTUAL ALONG THE GMM ID SET
% % Run GMMBoundsCounterfactualAutarky.m to generate Figure 2 Left panel
% GMMBoundsCounterfactualAutarky.m


%% LOCAL COUNTERFACTUAL ALONG THE GMM ID SET
% % Run GMMBoundsCounterfactualLocal.m to generate Figure 2 Right panel
% GMMBoundsCounterfactualLocal.m