%%% Elhanan Helpman, Oleg Itskhoki, Marc-Andreas Muendler and Stephen J. Redding (2016): 
%%% "Trade and Inequality: From Theory to Estimantion," Review of Economic Studies, forthcoming

%%% AUTARKY GMM BOUNDS COUNTERFACTUALS

%%% Produces Left panel of Figure 2 in the paper
%%% First run GMMBounds.m for ID SET



%% Autarky counterfactual along the GMM set

% number of draws (use 10M for precision and 100K for fast calculation)
BB = 10000000;      
RV = randn(BB,3);


DATA = [];
tic
for muh0 = muhmin:.01:2.046; % use step 0.01 for precision and step 0.1 for fast calculation

    su0 = sqrt(sH^2 - muh0.^2*Phihat*(1-Phihat) - 2*phihat*muh0 .* (Hbar1-Hbar0-muh0)/(lhat1-lhat0));
    ru0 = (Hbar1-Hbar0-muh0)/(lhat1-lhat0)./su0;
    
    z1 = (cHW*sH*sW - muh0*muw*Phihat*(1-Phihat) - (muh0*rw.*sw + muw*ru0*su0 )*phihat )/su0^2;
    z2 = bhat*(1-ru0^2) + ru0*rw.*sw/su0;
    z3 = muw/muh0;
    z4 = (muw/muh0*su0^2 - sw.^2)/su0^2./(1-muw/muh0);

    [fit0, ind0] = min((z1-z2).^2);
    muw0 = muw(ind0);
    rw0 = rw(ind0);
    sw0 = sw(ind0);
    zeta0 = z1(ind0);
     
    sv0 = sqrt(sw0^2-zeta0^2*su0^2);
    rv0 = (rw0*sw0-zeta0*ru0*su0)/sv0;
    
    [fitc, indc] = min((z1-z3).^2);
    muwc = muw(indc);
    
    betaimpl = (z1(indc)*su0^2-ru0*su0*rw(indc)*sw(indc))/su0^2/(1-ru0^2);
    
    pix = (muw0 - bhat*muh0) + (lhat1 + lhat0)*(rw0*sw0 - bhat*ru0*su0 );
    Rw2 = ( (2*z2(ind0)-bhat)*bhat*su0^2 + Phihat*(1-Phihat)*(bhat*muh0+pix)*(2*muw0-bhat*muh0-pix) ...
        + 2*phihat*( bhat*(muw0-bhat*muh0-pix)*ru0*su0 + (bhat*muh0+pix)*rw0*sw0 ) ) ...
        / ( sw0^2 + Phihat*(1-Phihat)*muw0^2 + 2*phihat*muw0*rw0*sw0 ) ;
    
    SIGMA = [su0^2 zeta0*su0^2 ru0*su0; 
             zeta0*su0^2 sw0^2 rw0*sw0;
             ru0*su0 rw0*sw0 1];
         
    SHOCK = (sqrtm(SIGMA)*RV')';
    UU = SHOCK(:,1);
    WW = SHOCK(:,2);
    ZZ = SHOCK(:,3);
    IOTA  = zeros(BB,1);
    IOTA(ZZ>=fhat) = 1; 
    
    VARAUT = mean(WW.^2 .* exp(UU))/mean(exp(UU)) - (mean(WW .* exp(UU))/mean(exp(UU)))^2 ;
    
    VAROPEN = mean((muw0*IOTA+WW).^2 .* exp(muh0*IOTA+UU))/mean(exp(muh0*IOTA+UU)) ...
        - (mean( (muw0*IOTA+WW) .* exp(muh0*IOTA+UU))/mean(exp(muh0*IOTA+UU)))^2 ;
    
    VAROPENcomp = mean((WW).^2 .* exp(muh0*IOTA+UU))/mean(exp(muh0*IOTA+UU)) ...
        - (mean( (WW) .* exp(muh0*IOTA+UU))/mean(exp(muh0*IOTA+UU)))^2 ;
    
    DATA = [DATA; [muh0  ru0 muw0 rw(ind0) z1(ind0) fit0 muwc rw(indc) z1(indc) fitc betaimpl pix Rw2 ...
        VARAUT VAROPEN VAROPENcomp  exp(muh0*IOTA+UU)'*IOTA/sum(exp(muh0*IOTA+UU)) sv0 rv0 ]];
    
end
toc

MUH = DATA(:,1);
VAUT = DATA(:,14);
VOPEN = DATA(:,15);

CF = sqrt(VOPEN(MUH<2.046)./VAUT(MUH<2.046));

figure(21)
plot(MUH(MUH<2.046),sqrt(VOPEN(MUH<2.046)./VAUT(MUH<2.046))-1,'LineWidth',3)
hold on
plot([muhmin muhmax],[min(CF) min(CF)]-1,'k--','linewidth',1)
plot([muhmin muhmax],[max(CF) max(CF)]-1,'k--','linewidth',1)
xlim([muhmin 2.046])
ylim([0 .1])
text(.5,.066,'Lower bound','FontSize',16,'interpreter','latex')
text(.25,.084,'Upper bound','FontSize',16,'interpreter','latex')
set(gca,'FontSize',14)
set(gca,'xtick',[muhmin:(2.046-muhmin)/5:2.046])
set(gca,'xticklabel',[0:.2:1])
set(gca,'ytick',[0:.02:1.12])
set(gca,'yticklabel',[0:2:12])
xlabel('GMM identified set','FontSize',16,'interpreter','latex')
ylabel('Wage inequality (\% increase)','FontSize',16,'interpreter','latex')

print -depsc BoundsAutarky.eps