%%% Elhanan Helpman, Oleg Itskhoki, Marc-Andreas Muendler and Stephen J. Redding (2016): 
%%% "Trade and Inequality: From Theory to Estimantion," Review of Economic Studies, forthcoming

%%% MULTIDESTINATION STRUCTURAL MAXIMUM LIKELIHOOD ESTRIMATION

% Parameter estimates in Panel A of Table A3 in the paper

clear all
close all
cd '/home/sjredding/himr-restud/matlab/brazil'
clc

global K izt isu isv iru irv imh1 imh2 imh3 imw1 imw2 imw3 ifx1 ifx2 ifx3 X T eps MMM

%% ------ SELECT SPECIFICATION ------
% A : specA==1;
% B : specA==0;
%specA=1;
specA=0;


%% ------ PARAMETERS ------

K = 14;   % number of parameters to estimate

% indexes of the estimation parameters
izt = 1;    % zeta
isu = 2;    % sigma_u
isv = 3;    % sigma_v
iru = 4;    % rho_u
irv = 5;    % rho_v
imh1 = 6;   % mu_h1
imh2 = 7;   % mu_h2 (corresponds to increment mu_h2-mu_h1 in the paper)
imh3 = 8;   % mu_h3 (corresponds to increment mu_h3-mu_h2 in the paper)
imw1 = 9;   % mu_w1
imw2 = 10;  % mu_w2 (corresponds to increment mu_w2-mu_w1 in the paper)
imw3 = 11;  % mu_w3 (corresponds to increment mu_w3-mu_w2 in the paper)
ifx1 = 12;  % f_x1
ifx2 = 13;  % f_x2
ifx3 = 14;  % f_x3

eps = 1e-8; % precision
MMM = 1e+4; % upper bounds

% Parameter lower and upper bounds
LB0 = [-1 eps eps -3 -3 -5 -5 -5 0 0 0 0 0 0]';
UB0 = [1 25 25 3 3 5 5 5 5 5 5 5 5 5]';



%% ------ ESTIMATION ------

THETA_MLE = zeros(K,T); % matrix of estimated parameters


T = 1998-1986+1;    % number of years for estimation
yr = 1986-1;  % initial year for estimation
for t = 1:T
    yr = yr + 1
    
    %% --- LOAD DATA X --- 
    if yr==1986;     data = csvread('/data/sjredding/himr-restud/condwtvfe/mincer/agg-tmincer-1986-fun.csv');
    elseif yr==1987; data = csvread('/data/sjredding/himr-restud/condwtvfe/mincer/agg-tmincer-1987-fun.csv');
    elseif yr==1988; data = csvread('/data/sjredding/himr-restud/condwtvfe/mincer/agg-tmincer-1988-fun.csv');
    elseif yr==1989; data = csvread('/data/sjredding/himr-restud/condwtvfe/mincer/agg-tmincer-1989-fun.csv');
    elseif yr==1990; data = csvread('/data/sjredding/himr-restud/condwtvfe/mincer/agg-tmincer-1990-fun.csv');
    elseif yr==1991; data = csvread('/data/sjredding/himr-restud/condwtvfe/mincer/agg-tmincer-1991-fun.csv');
    elseif yr==1992; data = csvread('/data/sjredding/himr-restud/condwtvfe/mincer/agg-tmincer-1992-fun.csv');
    elseif yr==1993; data = csvread('/data/sjredding/himr-restud/condwtvfe/mincer/agg-tmincer-1993-fun.csv');
    elseif yr==1994; data = csvread('/data/sjredding/himr-restud/condwtvfe/mincer/agg-tmincer-1994-fun.csv');
    elseif yr==1995; data = csvread('/data/sjredding/himr-restud/condwtvfe/mincer/agg-tmincer-1995-fun.csv');
    elseif yr==1996; data = csvread('/data/sjredding/himr-restud/condwtvfe/mincer/agg-tmincer-1996-fun.csv');
    elseif yr==1997; data = csvread('/data/sjredding/himr-restud/condwtvfe/mincer/agg-tmincer-1997-fun.csv');
    elseif yr==1998; data = csvread('/data/sjredding/himr-restud/condwtvfe/mincer/agg-tmincer-1998-fun.csv');
    end
    %     Columns in firm-year data;

    % Column 1 : cnpj_radic; 
    % Column 2 : firm_subsibge; 
    % Column 3 : year; 
    % Column 4 : lwageyr;   
    % Column 5 : wageyr; 
    % Column 6 : reslwageyr; 
    % Column 7 : obslwageyr; 
    % Column 8 : felwageyr; 
    % Column 9 : indexp; 
    % Column 10 : employ; 
    % Column 11 : indimp; 
    % Column 12 : indexpusa; 
    % Column 13 : meso; 
    % Column 14 : state; 
    % Column 15 : lwageyrmeso; 
    % Column 16 : felwageyrmeso; 
    % Column 17 : lemploymeso;
    % Column 18 : indexpbin1; 
    % Column 19 : indexpbin2; 
    % Column 20 : indexpbin3; 
    % Column 21 : forworker;
    % Column 22 : nexpbin1; 
    % Column 23 : nexpbin2; 
    % Column 24 : nexpbin3;

    N  = size(data,1);        % number of observations
    H  = log(data(:,10));   % log employment
    W  = data(:,8);         % log wage 
    if specA==1;
    I3 = data(:,20);        % Spec A (>=11 destinations);          
    I2 = I3 + data(:,19);   % Spec A (2-10 destinations); 
    I1 = I2 + data(:,18);   % Spec A (at least 1 destination);
    elseif specA==0;
    I3 = data(:,24);        % Spec B (>=26 destinations); 
    I2 = I3 + data(:,23);   % Spec B (6-25 destinations);
    I1 = I2 + data(:,22); % Spec B (at least 1 destination);
    end;
    X  = [H W I1 I2 I3];      % data matrix
    
    
    
    %% --- INITIAL CONDITION --- 
    % ML parameters under restricted model with mu_h = mu_w = rho_u = rho_v = 0
    COVM = cov(X);
    Theta0 = [COVM(2,1)/COVM(1,1) std(H) std(W) 0 0 0 0 0 0 0 0 ...
        norminv(mean(1-I1),0,1) norminv(mean(1-I2),0,1)-norminv(mean(1-I1),0,1) ...
        norminv(mean(1-I3),0,1)-norminv(mean(1-I2),0,1)]';
    
    
    
    %% --- ESTIMATION ---
    
    % Optimization options
    options = optimset('display','iter','TolFun',eps,'TolX',eps);
       
    % Transformed initial conditions
    Theta0_tr = Theta0;
    Theta0_tr([isu; isv]) = Theta0([isu; isv]).^2;
    Theta0_tr([iru; irv; ifx1; ifx2; ifx3]) = Theta0([iru; irv; ifx1; ifx3; ifx3]) ...
        /sqrt(max(eps,1 - Theta0(iru)^2 - Theta0(irv)^2));
    
    % Constrained optimization 
    % see llf_md.m for the objective (-log-likelihood) function 
    % see strconstr_md.m for the structural constraint
    [Theta_mle_tr,ll,EXITFLAG,OUTPUT,LAMBDA,GRAD,HESSIAN] ...
        = fmincon('llf_md',Theta0_tr,[],[],[],[],LB0,UB0,'strconstr_md',options);
    
    % Reverse transformation
    Theta_mle = Theta_mle_tr;
    Theta_mle([isu; isv]) = sqrt(Theta_mle_tr([isu; isv]));
    Theta_mle([iru; irv; ifx1; ifx2; ifx3]) = Theta_mle_tr([iru; irv; ifx1; ifx2; ifx3]) ...
        /sqrt(1 + Theta_mle_tr(iru)^2 + Theta_mle_tr(irv)^2);
    
    
    THETA_MLE(:,t) = Theta_mle;
    
    disp(Theta_mle)
    
end


%% ------ Panel A of Table A3 (parameter estimates) ------
t = 1994-1986+1;    % baseline year 1994
disp('Multisector estimated paramteres (Specification A or B')
disp('rho_u, rho_v, mu_h1, mu_h2, mu_h3, mu_w1, mu_w2, mu_w3')
[THETA_MLE(iru,t) THETA_MLE(irv,t) ...
    THETA_MLE(imh1,t) THETA_MLE(imh1,t)+THETA_MLE(imh2,t) THETA_MLE(imh1,t)+THETA_MLE(imh2,t)+THETA_MLE(imh3,t)...
    THETA_MLE(imw1,t) THETA_MLE(imw1,t)+THETA_MLE(imw2,t) THETA_MLE(imw1,t)+THETA_MLE(imw2,t)+THETA_MLE(imw3,t)]


%% ------ SAVE PARAMETER ESTIMATES ------
% If Specification A
if specA==1;
dlmwrite('THETA_MLEmd.csv',THETA_MLE,'precision','%14.6f','newline','pc'); 
% If Specification B
elseif specA==0;
dlmwrite('THETA_MLEmd_alt.csv',THETA_MLE,'precision','%14.6f','newline','pc'); 
end;
