%%% OLEG ITSKHOKI: HIMR, JANUARY 2013 (FIRST CODE: SEPTEMBER 2011)
%%% TRADE AND INEQUALITY: FROM THEORY TO ESTIMATION
%%% LOG-LIKELIHOOD FUNCTION FOR BASELINE MLE

function [f] = llf(Theta)

global izt isu isv iru irv imh imw ifx X eps

%%% ------ DATA X ------ %%%
H = X(:,1);     % log employment
W = X(:,2);     % wage variable
I = X(:,3);     % export status
N = size(X,1);  % number of firms

%%% ------ PARAMERERS ------ %%%
ztl  = Theta(izt);   % zeta
su2l = Theta(isu);   % sigma_u^2, transformed
sv2l = Theta(isv);   % sigma_v^2, transformed
rul  = Theta(iru);   % \tilde{rho}_u = rho_u/sqrt{1 - rho_u^2 - rho_v^2 }, transformed
rvl  = Theta(irv);   % \tilde{rho}_v = rho_v/sqrt{1 - rho_u^2 - rho_v^2 }, transformed
mhl  = Theta(imh);   % mu_h
mwl  = Theta(imw);   % mu_w
fxl  = Theta(ifx);   % \tilde{f} = f/sqrt{1 - rho_u^2 - rho_v^2 }, transformed

ahl = mean( H - mhl*I );    % alpha_h
awl = mean( W - mwl*I );    % alpha_w



%%%----------------------------%%%
% conditional mean E{z|h,w}
ml = rul * (H - ahl - mhl*I) / sqrt(max(su2l,eps)) ...
    + rvl * ( (W - awl - mwl*I) - ztl * (H - ahl - mhl*I) ) / sqrt(max(sv2l,eps));


llt = - N/2 * ( log(max(su2l,eps)) + log(max(sv2l,eps)) ) ...
    - (H - ahl - mhl*I)' * (H - ahl - mhl*I) / (2*max(su2l,eps)) ...
    - ((W - awl - mwl*I) - ztl*(H - ahl - mhl*I))' * ((W - awl - mwl*I) - ztl*(H - ahl - mhl*I)) / (2*max(sv2l,eps)) ...
    + (1-I)' * log( max( normcdf( fxl - ml ,0,1) ,eps) ) ...
    + I' * log( max( 1 - normcdf( fxl - ml ,0,1) ,eps) );
    
f = - llt/N ;