%%%% OLEG ITSKHOKI: HIMR, JANUARY 2013 (FIRST CODE: SEPTEMBER 2011)
%%%% TRADE AND INEQUALITY: FROM THEORY TO ESTIMATION
%%%% MAIN CODE FOR THE BASELINE ML ESTRIMATION

clear all
close all

%%%% Users;
%%%% 1 : HIMR server;
%%%% 2 : Steve mac dropbox;
%%%% 3 : Oleg mac dropbox;

user=1;

if user==1;
cd /Users/reddings/Dropbox/HIMR/Restud3/replication/himr-restud/matlab/colombia/matlab/;
end;

clc

global K izt isu isv iru irv imh imw ifx X T eps MMM




%%% ------ PARAMETERS ------ %%%
K = 8;   % number of parameters to estimate
% indexes of the estimation parameters
izt = 1;    % zeta
isu = 2;    % sigma_u
isv = 3;    % sigma_v
iru = 4;    % rho_u
irv = 5;    % rho_v
imh = 6;    % mu_h
imw = 7;    % mu_w
ifx = 8;    % f

eps = 1e-8; % precision
MMM = 1e+4; % upper bounds
% Parameter lower and upper bounds
LB0 = [-1 eps eps -3 -3 0 0 -5]';
UB0 = [1 25 25 3 3 5 5 5]';



%%% ------ ESTIMATION ------ %%%
% THETA_MLE0 = csvread('THETA_MLE.csv'); 
THETA_MLE = zeros(K,T); % matrix of estimated parameters
THETA_GMMO = zeros(10,T);
THETA_GMME = zeros(10,T);
CLOSED = zeros(37,T);

T = 1991-1981+1;    % number of years for estimation
yr = 1981-1;  % initial year for estimation
for t = 1:T
    yr = yr + 1
    
    % --- LOAD DATA X --- %
    %COLUMN 1 : plant 
    %COLUMN 2 : year 
    %COLUMN 3 : sic3 
    %COLUMN 4 : employment 
    %COLUMN 5 : wage 
    %COLUMN 6 : exporter 
    if yr==1981;     data = csvread('../stata/coldata81.csv');
    elseif yr==1982; data = csvread('../stata/coldata82.csv');
    elseif yr==1983; data = csvread('../stata/coldata83.csv');
    elseif yr==1984; data = csvread('../stata/coldata84.csv');
    elseif yr==1985; data = csvread('../stata/coldata85.csv');
    elseif yr==1986; data = csvread('../stata/coldata86.csv');
    elseif yr==1987; data = csvread('../stata/coldata87.csv');
    elseif yr==1988; data = csvread('../stata/coldata88.csv');
    elseif yr==1989; data = csvread('../stata/coldata89.csv');
    elseif yr==1990; data = csvread('../stata/coldata90.csv');
    elseif yr==1991; data = csvread('../stata/coldata91.csv');
    end

    N = size(data,1);       % number of observations
    H = log(data(:,4));     % log employment
    W = log(data(:,5));     % log wage 
    I = data(:,6);          % export status
    
    X = [H W I];            % data matrix
    
    display('Year is');
    display(yr)
    display('Number of firms is');
    display(N)
    
    % --- INITIAL CONDITION --- %
    % parameters under mu_h = mu_w = rho_u = rho_v = 0
    COVM = cov(X);
    Theta0 = [COVM(2,1)/COVM(1,1) std(H) std(W) 0 0 0 0 norminv(mean(1-I),0,1)]';
    % previous estimates
%     Theta0 = THETA_MLE0(:,yr-1986+1);
    
    
    
    % --- ESTIMATION --- %
    
    % Optimization options
    options = optimset('display','iter','TolFun',eps,'TolX',eps,'Algorithm','interior-point');
    
       
    % Transformed initial conditions
    Theta0_tr = Theta0;
    Theta0_tr([isu; isv]) = Theta0([isu; isv]).^2;
    Theta0_tr([iru; irv; ifx]) = Theta0([iru; irv; ifx]) ...
        /sqrt(max(eps,1 - Theta0(iru)^2 - Theta0(irv)^2));
    
A=[]; b=[];
%     % mu_h,mu_w>0
%     A = zeros(4,K); A(1,imh) = -1; A(2,imw) = -1; A(3,iru)=1; A(4,irv)=1; b = zeros(4,1);
%     % rho_v=0
%     A = zeros(2,K); A(1,imw) = 1; A(2,imh)=1; b = zeros(2,1);
% STRUCTURAL CONSTRAINTS;
    [Theta_mle_tr,ll,EXITFLAG,OUTPUT,LAMBDA,GRAD,HESSIAN] ...
       = fmincon('llf',Theta0_tr,[],[],A,b,LB0,UB0,'strconstr',options);
% UNCONSTRAINED;
%     [Theta_mle_tr,ll,EXITFLAG,OUTPUT,LAMBDA,GRAD,HESSIAN] ...
%         = fmincon('llf',Theta0_tr,[],[],A,b,LB0,UB0,[],options);
     
    % Reverse transformation
    Theta_mle = Theta_mle_tr;
    Theta_mle([isu; isv]) = sqrt(Theta_mle_tr([isu; isv]));
    Theta_mle([iru; irv; ifx]) = Theta_mle_tr([iru; irv; ifx]) ...
        /sqrt(1 + Theta_mle_tr(iru)^2 + Theta_mle_tr(irv)^2);
    
    
   THETA_MLE(:,t) = Theta_mle;

    
    
end;     
    
    
    

% STRUCTURAL CONSTRAINT;
dlmwrite('THETA_MLEsc.csv',THETA_MLE,'precision','%14.6f','newline','pc');


% BASELINE 1985 ESTIMATES;
display('Baseline 1985 Estimates');
display('mu_h');
THETA_MLE(6,5)
display('mu_w');
THETA_MLE(7,5)
display('rho_u');
THETA_MLE(4,5)
display('rho_v');
THETA_MLE(5,5)
display('f');
THETA_MLE(8,5)

