%%% OLEG ITSKHOKI: HIMR, JANUARY 2013 (FIRST CODE: SEPTEMBER 2011)
%%% TRADE AND INEQUALITY: FROM THEORY TO ESTIMATION
%%% MAIN CODE FOR MOMENTS

clear all
close all

%%%% Users;
%%%% 1 : HIMR server;
%%%% 2 : Steve mac dropbox;
%%%% 3 : Oleg mac dropbox;

user=1;

if user==1;
cd /Users/reddings/Dropbox/HIMR/Restud3/replication/himr-restud/matlab/colombia/matlab/;
end;

clc

global K izt isu isv iru irv imh imw ifx X




%%% ------ PARAMETERS ------ %%%
K = 8;   % number of parameters to estimate
% indexes of the estimation parameters
izt = 1;    % zeta
isu = 2;    % sigma_u
isv = 3;    % sigma_v
iru = 4;    % rho_u
irv = 5;    % rho_v
imh = 6;    % mu_h
imw = 7;    % mu_w
ifx = 8;    % f



%%% ------ DATA ------ %%%
%COLUMN 1 : plant 
%COLUMN 2 : year 
%COLUMN 3 : sic3 
%COLUMN 4 : employment 
%COLUMN 5 : wage 
%COLUMN 6 : exporter 
data = csvread('../stata/coldata85.csv');
yr = 1985;
t = yr-1981+1;

N = size(data,1);       % number of observations
H = log(data(:,4));     % log employment
W = log(data(:,5));     % log wage 
I = data(:,6);          % export status
X = [H W I];            % data matrix



%%% ------ SIMULATED DATA ------ %%%
% --- Parameters of the structural model
THETA_MLE = csvread('THETA_MLEsc.csv'); 
TH = THETA_MLE(:,t);
ah = mean( H - TH(imh)*I );    % alpha_h
aw = mean( W - TH(imw)*I );    % alpha_w

% --- Generating draws of (u,v,z) --- %
% Covariance matrix for the shocks
Sigma = [TH(isu)^2 0 TH(iru)*TH(isu); 0 TH(isv)^2 TH(irv)*TH(isv); ...
    TH(iru)*TH(isu) TH(irv)*TH(isv) 1];
% Nx3 matrix of observations of (u,v,z)
Rt = mvnrnd(zeros(1,3), Sigma , N*10 );    % if truncated, use floor(N/(1 - normcdf(log(5),ah,TH(isu)))) for size
UU = Rt(:,1);
VV = Rt(:,2);
ZZ = Rt(:,3);
% --- Model-simulated data (h,w,iota)
IM = zeros(N*10 ,1);  % if truncated, use floor(N/(1 - normcdf(log(5),ah,TH(isu)))) for size
IM( ZZ >= TH(ifx) ) = 1;
HM = ah + TH(imh)*IM + UU;
WM = aw + TH(imw)*IM + TH(izt)*UU + VV;
XM = [HM WM IM];
NM = size(XM,1);




%%% ------ FIRM MOMENTS ------ %%%
MOM = zeros(37,2);
% --- Unconditional
MOM(1,:) = [mean(H) mean(HM)]; % mean employment
MOM(2,:) = [mean(W) mean(WM)]; % mean wages
MOM(3,:) = [std(H) std(HM)];    % st. dev. employment
MOM(4,:) = [std(W) std(WM)];    % st. dev. wages
MOM(5,:) = [corr(H,W) corr(HM,WM)]; % corr empl & wages
MOM(6,:) = [mean(I) mean(IM)]; % fraction exporters





% --- Non-exporters
MOM(8,:)  = [(1-I)'*H/sum(1-I) (1-IM)'*HM/sum(1-IM)]; % mean employment
MOM(9,:)  = [(1-I)'*W/sum(1-I) (1-IM)'*WM/sum(1-IM)]; % mean wages
MOM(10,:)  = [std(H(I==0)) std(HM(IM==0))];    % st. dev. employment
MOM(11,:) = [std(W(I==0)) std(WM(IM==0))];    % st. dev. wages
MOM(12,:) = [corr(H(I==0),W(I==0)) corr(HM(IM==0),WM(IM==0))]; % corr empl & wages
% --- Exporters
MOM(14,:)  = [I'*H/sum(I) IM'*HM/sum(IM)]; % mean employment
MOM(15,:)  = [I'*W/sum(I) IM'*WM/sum(IM)]; % mean wages
MOM(16,:)  = [std(H(I==1)) std(HM(IM==1))];    % st. dev. employment
MOM(17,:) = [std(W(I==1)) std(WM(IM==1))];    % st. dev. wages
MOM(18,:) = [corr(H(I==1),W(I==1)) corr(HM(IM==1),WM(IM==1))]; % corr empl & wages



%%% ------ WORKER MOMENTS ------ %%%
% --- employment weights
wH = max(1,round(exp(H)));
wHM = max(1,round(exp(HM)));
% --- mean log worker wage
MOM(20,:) = [wH'*W/sum(wH) wHM'*WM/sum(wHM)];  % unconditional
MOM(21,:) = [wH(I==0)'*W(I==0)/sum(wH(I==0)) ...
    wHM(IM==0)'*WM(IM==0)/sum(wHM(IM==0))];  % non-exporters
MOM(22,:) = [wH(I==1)'*W(I==1)/sum(wH(I==1)) ...
    wHM(IM==1)'*WM(IM==1)/sum(wHM(IM==1))];  % exporters
% --- st. dev. log worker wage
MOM(24,:) = [ sqrt(wH'*W.^2/sum(wH) - (wH'*W/sum(wH))^2) ...
    sqrt(wHM'*WM.^2/sum(wHM) - (wHM'*WM/sum(wHM))^2)];  % unconditional
MOM(25,:) = [ sqrt(wH(I==0)'*W(I==0).^2/sum(wH(I==0)) - (wH(I==0)'*W(I==0)/sum(wH(I==0)))^2) ...
    sqrt(wHM(IM==0)'*WM(IM==0).^2/sum(wHM(IM==0)) - (wHM(IM==0)'*WM(IM==0)/sum(wHM(IM==0)))^2)];  % non-exporters
MOM(26,:) = [ sqrt(wH(I==1)'*W(I==1).^2/sum(wH(I==1)) - (wH(I==1)'*W(I==1)/sum(wH(I==1)))^2) ...
    sqrt(wHM(IM==1)'*WM(IM==1).^2/sum(wHM(IM==1)) - (wHM(IM==1)'*WM(IM==1)/sum(wHM(IM==1)))^2)];  % exporters
% --- employment share of exporters
MOM(28,:) = [I'*wH/sum(wH) IM'*wHM/sum(wHM)];





%%% ------ WAGE INEQUALITY ------ %%%
% --- Data
[Wsrt,ind_Wsrt] = sort(W);
cumH_Wsrt = cumsum(wH(ind_Wsrt))/sum(wH);
% --- Gini (discrete probability formula from Wikipedia)
S = cumsum( wH(ind_Wsrt).*exp(Wsrt) / sum(wH) );
MOM(30,1) = 1 - wH(ind_Wsrt)'* (S + [0; S(1:end-1,1)]) / sum(wH) / S(end,1);
% --- 90/10, 90/50, 50/10 ratios
qeps = 0.0005;
ind10 = find((cumH_Wsrt>0.1-qeps/10)&(cumH_Wsrt<.1+qeps/10));
ind50 = find((cumH_Wsrt>0.5-qeps)&(cumH_Wsrt<.5+qeps));
ind90 = find((cumH_Wsrt>0.9-qeps)&(cumH_Wsrt<.9+qeps));
MOM(31,1) = exp( mean(W(ind_Wsrt(ind90))) - mean(W(ind_Wsrt(ind10))));
MOM(32,1) = exp( mean(W(ind_Wsrt(ind90))) - mean(W(ind_Wsrt(ind50))));
MOM(33,1) = exp( mean(W(ind_Wsrt(ind50))) - mean(W(ind_Wsrt(ind10))));

% --- Structural Model
[Wsrt,ind_Wsrt] = sort(WM);
cumH_Wsrt = cumsum(wHM(ind_Wsrt))/sum(wHM);
% --- Gini (discrete probability formula from Wikipedia)
S = cumsum( wHM(ind_Wsrt).*exp(Wsrt) / sum(wHM) );
MOM(30,2) = 1 - wHM(ind_Wsrt)'* (S + [0; S(1:end-1,1)]) / sum(wHM) / S(end,1);
% --- 90/10, 90/50, 50/10 ratios
qeps = 0.0005;
ind10 = find((cumH_Wsrt>0.1-qeps/10)&(cumH_Wsrt<.1+qeps/10));
ind50 = find((cumH_Wsrt>0.5-qeps)&(cumH_Wsrt<.5+qeps));
ind90 = find((cumH_Wsrt>0.9-qeps)&(cumH_Wsrt<.9+qeps));
MOM(31,2) = exp( mean(WM(ind_Wsrt(ind90))) - mean(WM(ind_Wsrt(ind10))));
MOM(32,2) = exp( mean(WM(ind_Wsrt(ind90))) - mean(WM(ind_Wsrt(ind50))));
MOM(33,2) = exp( mean(WM(ind_Wsrt(ind50))) - mean(WM(ind_Wsrt(ind10))));





%%% ------ SIZE AND EXPORTER WAGE PREMIA ------ %%%
btmp = ([ones(N,1) H I]'*[ones(N,1) H I])\([ones(N,1) H I]'*W);
MOM(35:36,1) = btmp(2:3,1);
MOM(37,1) = 1-(W - [ones(N,1) H I]*btmp)'*(W - [ones(N,1) H I]*btmp)/ ( (W-mean(W))'*(W-mean(W)) );

btmp = ([ones(NM,1) HM IM]'*[ones(NM,1) HM IM])\([ones(NM,1) HM IM]'*WM);
MOM(35:36,2) = btmp(2:3,1);
MOM(37,2) = 1-(WM - [ones(NM,1) HM IM]*btmp)'*(WM - [ones(NM,1) HM IM]*btmp)/ ( (WM-mean(WM))'*(WM-mean(WM)) );










%%% ------ FIRM DENSITIES ------ %%%
[fH,xH]=ksdensity(H);
[fHM,xHM]=ksdensity(HM);
[fW,xW]=ksdensity(W);
[fWM,xWM]=ksdensity(WM);

[fHd,xHd]=ksdensity(H(I==0));
[fHx,xHx]=ksdensity(H(I==1));
[fHMd,xHMd]=ksdensity(HM(IM==0));
[fHMx,xHMx]=ksdensity(HM(IM==1));

[fWd,xWd]=ksdensity(W(I==0));
[fWx,xWx]=ksdensity(W(I==1));
[fWMd,xWMd]=ksdensity(WM(IM==0));
[fWMx,xWMx]=ksdensity(WM(IM==1));


figure(1)
subplot(2,2,1)
plot(xH,fH,'Color','blue','LineStyle','-','LineWidth',1.5)
hold on
plot(xHM,fHM,'Color','red','LineStyle','--','LineWidth',1.5)
title('Panel A : Firm Employment','FontSize',8)
ylabel('Log Employment','FontSize',8)
axis([0 9 min(fH) max(max(fH,fHM))]);
subplot(2,2,2)
plot(xW,fW,'Color','blue','LineStyle','-','LineWidth',1.5)
hold on
plot(xWM,fWM,'Color','red','LineStyle','--','LineWidth',1.5)
title('Panel B : Firm Wages','FontSize',8)
ylabel('Log Wage Component','FontSize',8)
axis([4 8 min(fW) max(max(fW,fWM))]);
subplot(2,2,3)
plot(xHd,fHd,'-bo','LineWidth',1.5,'MarkerSize',5)
hold on
plot(xHx,fHx,'-bx','LineWidth',1.5,'MarkerSize',5)
plot(xHMd,fHMd,'--ro','LineWidth',1.5,'MarkerSize',5)
plot(xHMx,fHMx,'--rx','LineWidth',1.5,'MarkerSize',5)
title('Panel C : Firm Employment and Exporting','FontSize',8)
ylabel('Log Employment','FontSize',8)
temp1=min(fHd,fHx);
temp1=min(temp1,fHMd);
temp1=min(temp1,fHMx);
temp1=min(temp1);
temp2=max(fHd,fHx);
temp2=max(temp2,fHMd);
temp2=max(temp2,fHMx);
temp2=max(temp2);
axis([0 9 temp1 temp2]);
subplot(2,2,4)
plot(xWd,fWd,'-bo','LineWidth',1.5,'MarkerSize',5)
hold on
plot(xWx,fWx,'-bx','LineWidth',1.5,'MarkerSize',5)
plot(xWMd,fWMd,'--ro','LineWidth',1.5,'MarkerSize',5)
plot(xWMx,fWMx,'--rx','LineWidth',1.5,'MarkerSize',5)
title('Panel D : Firm Wages and Exporting','FontSize',8)
ylabel('Log Wage Component','FontSize',8)
temp1=min(fWd,fWx);
temp1=min(temp1,fWMd);
temp1=min(temp1,fWMx);
temp1=min(temp1);
temp2=max(fWd,fWx);
temp2=max(temp2,fWMd);
temp2=max(temp2,fWMx);
temp2=max(temp2);
axis([4 8 temp1 temp2]);
hold off;
h=axes('Position',[0 0 1 1],'Visible','off');
text(0.06,0.015,'Note: Data Blue Solid Line; Model Red Dashed Line; Exporter x; Non-exporter o.','FontSize',8);
print -dpdf Columbia_Firms_Fit.pdf;







%%% ------ WORKER DENSITIES ------ %%%
[fW,xW]=ksdensity(W,'weights',wH);
[fWM,xWM]=ksdensity(WM,'weights',wHM);
[fWd,xWd]=ksdensity(W(I==0),'weights',wH(I==0));
[fWx,xWx]=ksdensity(W(I==1),'weights',wH(I==1));
[fWMd,xWMd]=ksdensity(WM(IM==0),'weights',wHM(IM==0));
[fWMx,xWMx]=ksdensity(WM(IM==1),'weights',wHM(IM==1));





figure(2)
subplot(1,2,1)
plot(xW,fW,'Color','blue','LineStyle','-','LineWidth',1.5)
hold on
plot(xWM,fWM,'Color','red','LineStyle','--','LineWidth',1.5)
title('Panel A: Worker Wages','FontSize',8)
ylabel('Log Wage Component','FontSize',8)
axis([4 8 min(min(fW,fWM)) max(max(fW,fWM))]);
subplot(1,2,2)
plot(xWd,fWd,'-bo','LineWidth',1.5,'MarkerSize',5)
hold on
plot(xWx,fWx,'-bx','LineWidth',1.5,'MarkerSize',5)
plot(xWMd,fWMd,'--ro','LineWidth',1.5,'MarkerSize',5)
plot(xWMx,fWMx,'--rx','LineWidth',1.5,'MarkerSize',5)
title('Panel B: Worker Wages and Exporting','FontSize',8)
ylabel('Log Wage Component','FontSize',8)
temp1=min(fWd,fWx);
temp1=min(temp1,fWMd);
temp1=min(temp1,fWMx);
temp1=min(temp1);
temp2=max(fWd,fWx);
temp2=max(temp2,fWMd);
temp2=max(temp2,fWMx);
temp2=max(temp2);
axis([4 8 temp1 temp2]);
hold off;
h=axes('Position',[0 0 1 1],'Visible','off');
text(0.06,0.015,'Note: Data Blue Solid Line; Model Red Dashed Line; Exporter x; Non-exporter o.','FontSize',8);
print -dpdf Columbia_Workers_Fit.pdf;









