%%%% Matlab code for Monte Carlo;
%%%% Produces Figure D1 in the Online Supplement;

clear all
close all

%%%% Users
%%%% 1 : HIMR server;
%%%% 2 : Steve mac dropbox;
%%%% 3 : Oleg mac dropbox;

user=1;

if user==1;
cd /home/sjredding/matlab/himr-restud/matlab/montecarlo;
elseif user==2;
cd /Users/reddings/Dropbox/HIMR/Restud3/replication/himr-restud/matlab/montecarlo/
end;

clc

global K izt isu isv iru irv imh imw ifx X T eps MMM

% *******************************************;
% **** Define parameters to be estimated ****;
% *******************************************;

%%% ------ PARAMETERS ------ %%%
K = 8;   % number of parameters to estimate
% indexes of the estimation parameters
izt = 1;    % zeta
isu = 2;    % sigma_u
isv = 3;    % sigma_v
iru = 4;    % rho_u
irv = 5;    % rho_v
imh = 6;   % mu_h1
imw = 7;   % mu_w1
ifx = 8;  % f_x1

eps = 1e-8; % precision
MMM = 1e+4; % upper bounds
% Parameter lower and upper bounds
LB0 = [-1 eps eps -3 -3 -5 -5 -5]';
UB0 = [1 25 25 3 3 5 5 5]';

% Set default random number stream;
s = RandStream('mt19937ar','Seed',1);
RandStream.setGlobalStream(s);

% *************************;
% **** TRUE PARAMETERS ****;
% *************************;

ah = 0;     % alpha_h
aw = 0;     % alphga_w
yh = 1;    % (above 1 in the data)
yw = 0.5;   % (around zero in the data)
zeta = yw/yh;
f = norminv(0.935758,0,1);     % (8% exporters)
sq = 1.1;    % sigma_theta
sn = 0.8;    % sigma_eta
rq = 0.4;  
rn = 0.2;  

Theta_true=[zeta; sq; sn; rq; rn; yh; yw; f];

% **********************************;
% **** GENERATE DATA FROM MODEL ****;
% **********************************;

%%%% 50 replications;

T = 50;
THETA_MLE = zeros(K,T); % matrix of estimated parameters

for t=1:50;
%for t=1:1;

%%% DATA: Artificial data generated according to the model
N = 100000;   % number of observations
Rt = ...    % random draws for {theta,eta,u} for j=1:N
    mvnrnd(zeros(1,3),[sq^2 0 rq*sq; 0 sn^2 rn*sn; rq*sq rn*sn 1],N);
Q = Rt(:,1);    % vector of theta_j's
ETA = Rt(:,2);  % vector of eta_j's
U = Rt(:,3);    % vector of u's
% Export indicators;
I=(U>=f);
% Employment;
H = ah + Q + (yh.*I);  
% Wages;
W = aw + zeta*Q + ETA + (yw.*I);
% Data matrix;
X = [H W I];        





    % --- INITIAL CONDITION --- %
%     % parameters under mu_h = mu_w = rho_u = rho_v = 0
    COVM = cov(X);
    Theta0 = [COVM(2,1)/COVM(1,1) std(H) std(W) 0 0 0 0 norminv(mean(1-I),0,1)]';
    %-- previous estimates
    %Theta0 = THETA_MLEmd(:,yr-1986+1);
    
    
    
    % --- ESTIMATION --- %
    
    % Optimization options
    options = optimset('display','iter','TolFun',eps,'TolX',eps,'Algorithm','interior-point');
    
       
    % Transformed initial conditions
    Theta0_tr = Theta0;
    Theta0_tr([isu; isv]) = Theta0([isu; isv]).^2;
    Theta0_tr([iru; irv; ifx]) = Theta0([iru; irv; ifx]) ...
        /sqrt(max(eps,1 - Theta0(iru)^2 - Theta0(irv)^2));
    
%     % mu_h,mu_w>0
%     A = zeros(2,K); A(1,imh) = -1; A(2,imw) = -1; b = zeros(2,1);
%     % rho_v=0
%     A = zeros(1,K); A(1,irv) = 1; b = 0;
    % OTHOGONALITY CONSTRAINT;
    [Theta_mle_tr,ll,EXITFLAG,OUTPUT,LAMBDA,GRAD,HESSIAN] ...
       = fmincon('llf',Theta0_tr,[],[],[],[],LB0,UB0,'strconstr',options);
    % UNCONSTRAINED;
%      [Theta_mle_tr,ll,EXITFLAG,OUTPUT,LAMBDA,GRAD,HESSIAN] ...
%          = fmincon('llf',Theta0_tr,[],[],[],[],LB0,UB0,[],options);
    
    % Reverse transformation
    Theta_mle = Theta_mle_tr;
    Theta_mle([isu; isv]) = sqrt(Theta_mle_tr([isu; isv]));
    Theta_mle([iru; irv; ifx]) = Theta_mle_tr([iru; irv; ifx]) ...
        /sqrt(1 + Theta_mle_tr(iru)^2 + Theta_mle_tr(irv)^2);
    
    
    THETA_MLE(:,t) = Theta_mle;
    
    disp('>>>> True and Estimated parameters <<<<');
    disp('[zeta sq sn rq rn yh yw f]');
    disp([Theta_true Theta_mle]);
    
    
end;

% *************************************;
% **** Extract and Display Results ****;
% *************************************;

zeta=THETA_MLE(1,:);
sigma_u=THETA_MLE(2,:);
sigma_v=THETA_MLE(3,:);
rho_u=THETA_MLE(4,:);
rho_v=THETA_MLE(5,:);
mu_h=THETA_MLE(6,:);
mu_w=THETA_MLE(7,:);
f=THETA_MLE(8,:);

close all;
figure(1);
subplot(3,3,1);
xvalues1=0.5:0.1:1.5;
hist(mu_h,xvalues1);
title('Panel A : \mu_{h}','FontSize',8);
ylabel('Frequency','FontSize',8);
hold on;
line([Theta_true(6) Theta_true(6)],[0 T],'Color','red','LineStyle','-','LineWidth',1.5);
set(gca,'fontsize',8);
axis([0.5 1.5 0 T]);
hold off;
subplot(3,3,2);
xvalues2=0:0.1:1;
hist(mu_w,xvalues2);
title('Panel B : \mu_{w}','FontSize',8);
ylabel('Frequency','FontSize',8);
hold on;
line([Theta_true(7) Theta_true(7)],[0 T],'Color','red','LineStyle','-','LineWidth',1.5);
set(gca,'fontsize',8);
axis([0 1 0 T]);
hold off;
subplot(3,3,3);
xvalues3=-1:0.1:1;
hist(rho_u,xvalues3);
title('Panel C : \rho_{u}','FontSize',8);
ylabel('Frequency','FontSize',8);
hold on;
line([Theta_true(4) Theta_true(4)],[0 T],'Color','red','LineStyle','-','LineWidth',1.5);
set(gca,'fontsize',8);
axis([-1 1 0 T]);
hold off;
subplot(3,3,4);
xvalues4=-1:0.1:1;
hist(rho_v,xvalues4);
title('Panel D : \rho_{v}','FontSize',8);
ylabel('Frequency','FontSize',8);
hold on;
line([Theta_true(5) Theta_true(5)],[0 T],'Color','red','LineStyle','-','LineWidth',1.5);
set(gca,'fontsize',8);
axis([-1 1 0 T]);
hold off;
subplot(3,3,5);
xvalues5=0.5:0.1:1.5;
hist(sigma_u,xvalues5);
title('Panel D : \sigma_{u}','FontSize',8);
ylabel('Frequency','FontSize',8);
hold on;
line([Theta_true(2) Theta_true(2)],[0 T],'Color','red','LineStyle','-','LineWidth',1.5);
hold off;
set(gca,'fontsize',8);
axis([0.5 1.5 0 T]);
subplot(3,3,6);
xvalues6=0.5:0.1:1.5;
hist(sigma_v,xvalues6);
title('Panel E : \sigma_{v}','FontSize',8);
ylabel('Frequency','FontSize',8);
hold on;
line([Theta_true(3) Theta_true(3)],[0 T],'Color','red','LineStyle','-','LineWidth',1.5);
set(gca,'fontsize',8);
axis([0.5 1.5 0 T]);
hold off;
subplot(3,3,7);
xvalues7=1:0.1:2;
hist(f,xvalues7);
title('Panel F : f','FontSize',8);
ylabel('Frequency','FontSize',8);
hold on;
line([Theta_true(8) Theta_true(8)],[0 T],'Color','red','LineStyle','-','LineWidth',1.5);
set(gca,'fontsize',8);
axis([1 2 0 T]);
hold off;
subplot(3,3,8);
xvalues8=0:0.1:1;
hist(zeta,xvalues8);
title('Panel G : \zeta','FontSize',8);
ylabel('Frequency','FontSize',8);
hold on;
line([Theta_true(1) Theta_true(1)],[0 T],'Color','red','LineStyle','-','LineWidth',1.5);
set(gca,'fontsize',8);
axis([0 1 0 T]);
hold off;

print -dpdf montecarloresults_final_orth.pdf;



