
#delimit;

clear;
clear matrix;
set mem 30000m;
set matsize 11000;
set more off;
capture log close;

**********************************************************************************************;
**** Robustness test holding workforce composition constant at beginning of sample values ****;
**********************************************************************************************;

global dofiles="/home/sjredding/himr-restud/stata/dofiles";
global logs="/home/sjredding/himr-restud/stata/logs";
global input="/data/sjredding/himr-input";
global data="/data/sjredding/himr-restud";

*********************************;
* Code for Analysis of Variance *;
*********************************;

foreach yr of numlist 1986(1)1998 {;

log using $logs/cond/mincer/cmincer-compos-`yr'.log,replace;

use $input/rais-secex-all-workers-`yr'.dta, clear;

* Merge region information;

so cnpj_radic pis;
* Merge region data;
merge cnpj_radic using $data/geography/stateidentifiers-`yr'.dta;
tab _m;
keep if _m==3;
drop _m;

* Merge nationality information;
* nacionalidad;
* pis;
* ano;
* identificad;

so pis;
merge pis using $data/nationality/workers-template-`yr'-nacl-clean.dta;
tab _m;
drop _m;
so cnpj_radic pis;

* Define sample;

do $dofiles/routines/samplecond.do;

*********************;
* Setup and Loop    *;
*********************;

* Demographics variables;
local demog="indchild indyouth indadol indnasc indearly indpeak indlate indretir indfem";
gen demogcell=0;
replace demogcell=1 if indchild==1;
replace demogcell=2 if indyouth==1;
replace demogcell=3 if indadol==1;
replace demogcell=4 if indnasc==1;
replace demogcell=5 if indearly==1;
replace demogcell=6 if indpeak==1;
replace demogcell=7 if indlate==1;
replace demogcell=8 if indretir==1;

* Schooling variables;
local educ="indhigh indscoll indgrad";
gen educcell=0;
replace educcell=1 if indhigh==1;
replace educcell=2 if indscoll==1;
replace educcell=3 if indgrad==1;

* Basic occupation variables;
local occup="indprof indtech indwhit indsklb indunsklb";

xtile expqnt=temp_empr , nq(5);

* Define cells;
egen rcell=group(demogcell indfem educcell expqnt);

* Shares;
egen cnt=count(pis);
egen cnt_rcell=count(pis),by(rcell);
drop if cnt_rcell<5;
gen share=cnt_rcell/cnt;

* Mincer regressions;
areg lwageyr , abs(rcell) robust;

* Residual wage inequality;
predict temp if e(sample), res;
gen reslwageyr=temp;
drop temp;
* Observables;
predict temp if e(sample), xbd;
gen obslwageyr=temp;
drop temp;

* Composition term;
egen temp=sd(reslwageyr),by(rcell);
gen ares=temp*temp;
drop temp;

* Overall variance;
egen temp=sd(lwageyr);
gen tot=temp*temp;
drop temp;
* Variance observables;
egen temp=sd(obslwageyr);
gen obs=temp*temp;
drop temp;
* Variance residuals;
egen temp=sd(reslwageyr);
gen res=temp*temp;
drop temp;

gen year=`yr';

collapse (mean) tot obs res ares share demogcell indfem educcell expqnt, 
by(rcell year) fast;

so rcell year;
sa $data/cond/mincer/cmincer-`yr'.dta,replace;

log close;

};

******************************************;
**** Merge Mincer Firm Files Together ****;
******************************************;

clear;
u $data/cond/mincer/cmincer-1986.dta;
foreach yr of numlist 1987(1)1998 {;
append using $data/cond/mincer/cmincer-`yr'.dta;
};
so rcell year;
sa $data/cond/mincer/cmincer-all.dta, replace;



