
#delimit;

clear;
clear matrix;
set mem 30000m;
set matsize 11000;
set more off;
capture log close;

**********************************************************************;
**** Code to look at the role of compositional changes explaining ****;
**** changes in residual wage inequality                          ****;
**********************************************************************;

global dofiles="/home/sjredding/himr-restud/stata/dofiles";
global logs="/home/sjredding/himr-restud/stata/logs";
global graphs="/home/sjredding/himr-restud/stata/graphs";
global input="/data/sjredding/himr-input";
global data="/data/sjredding/himr-restud";

log using $logs/cond/mincer/cmincer_compos_anal.log, replace;

u $data/cond/mincer/cmincer-all.dta;

gen temp=share if year==1986;
egen share1986=max(temp),by(rcell);
drop temp;

gen wares=share*ares;
gen wares1986=share1986*ares;

collapse (mean) tot obs res demogcell indfem educcell expqnt (sum) wares wares1986 , by(year);

gen test=res-wares;
replace test=int(test*10000);
su test, d;
drop test;

gen test=res-wares1986;
replace test=int(test*10000);
su test, d;
drop test;

gen test=tot-(obs+res);
replace test=int(test*10000);
su test, d;
drop test;

****************;
**** Tables ****;
****************;

gen sh_obs=obs/tot;
gen sh_res=res/tot;
gen sh_wares=wares/tot;
gen sh_wares1986=wares1986/tot;

foreach var of varlist tot obs res wares wares1986 sh_obs sh_res sh_wares sh_wares1986 {;
gen temp=`var' if year==1986;
egen `var'_86=max(temp);
drop temp;
gen temp=`var' if year==1995;
egen `var'_95=max(temp);
drop temp;
};

foreach var of varlist tot obs res wares wares1986 {;
gen d_`var'_86=(`var'_95-`var'_86)/`var'_86; 
};

gen cnt_obs_86=(sh_obs_86*d_obs_86)/d_tot_86;
gen cnt_res_86=(sh_res_86*d_res_86)/d_tot_86;
gen cnt_wares_86=(sh_wares_86*d_wares_86)/d_tot_86;
gen cnt_wares1986_86=(sh_wares1986_86*d_wares1986_86)/d_tot_86;

********************************************;
**** Table H9 for the Online Supplement ****;
********************************************;

* Levels contribution;

list year sh_wares1986 if year==1994;

* Changes contribution;

list cnt_wares1986_86 if year==1994;

*********************************************;
**** Figure H9 for the Online Supplement ****;
*********************************************;

twoway (scatter wares1986 year, c(l) msymbol(i) lpattern(solid) lcolor(blue) lwidth(thick)),
graphregion(fcolor(gs16))
ytitle(Residual Wage Inequality)
xlabel(1986 1990 1994 1998)
saving($graphs/cond/mincer/resid_compos,replace)
;

graph export $graphs/cond/mincer/resid_compos.eps, as(eps) replace;

