
#delimit;

clear;
clear matrix;
set matsize 11000;
set more off;
capture log close;

************************************************************************************;
**** This file estimates time-varying firm fixed effects in a Mincer regression ****;
************************************************************************************;

global dofiles="/home/sjredding/himr-restud/stata/dofiles";
global logs="/home/sjredding/himr-restud/stata/logs";
global input="/data/sjredding/himr-input";
global data="/data/sjredding/himr-restud";

*********************************;
* Code for Analysis of Variance *;
*********************************;

foreach yr of numlist 1986(1)1998 {;

log using $logs/condwtvfe/mincer/tmincer-`yr'.log,replace;

use $input/rais-secex-all-workers-`yr'.dta, clear;

* Merge region information;

so cnpj_radic pis;
* Merge region data;
merge cnpj_radic using $data/geography/stateidentifiers-`yr'.dta;
tab _m;
keep if _m==3;
drop _m;

* Merge nationality information;
* nacionalidad;
* pis;
* ano;
* identificad;

so pis;
merge pis using $data/nationality/workers-template-`yr'-nacl-clean.dta;
tab _m;
keep if _m==1|_m==3;
drop _m;
so cnpj_radic pis;

* Define sample;

do $dofiles/routines/samplecond.do;

* Assume workers with missing nationality data are Brazilian;

replace forworker=0 if forworker==.;
replace useujap=0 if useujap==.;

*********************;
* Setup and Loop    *;
*********************;

* Demographics variables;
local demog="indchild indyouth indadol indnasc indearly indpeak indlate indretir indfem";

* Schooling variables;
local educ="indhigh indscoll indgrad";

* Basic occupation variables;
local occup="indprof indtech indwhit indsklb indunsklb";

xtile expqnt=temp_empr , nq(5);
tab expqnt,gen(tenure);

* Age;
gen age=12 if indchild==1;
replace age=16 if indyouth==1;
replace age=20 if indadol==1;
replace age=27 if indnasc==1;
replace age=34 if indearly==1;
replace age=44 if indpeak==1;
replace age=57 if indlate==1;
replace age=65 if indretir==1;

su if age==.;

* Loop;
gen reslwageyr=.;
gen obslwageyr=.;
gen felwageyr=.;
gen bchild=.;
gen byouth=.;
gen badol=.;
gen bnasc=.;
gen bearly=.;
gen bpeak=.;
gen blate=.;
gen bretir=.;
gen bfem=.;
gen bhigh=.;
gen bscoll=.;
gen bgrad=.;
gen btenure2=.;
gen btenure3=.;
gen btenure4=.;
gen btenure5=.;
gen sechild=.;
gen seyouth=.;
gen seadol=.;
gen senasc=.;
gen seearly=.;
gen sepeak=.;
gen selate=.;
gen seretir=.;
gen sefem=.;
gen sehigh=.;
gen sescoll=.;
gen segrad=.;
gen setenure2=.;
gen setenure3=.;
gen setenure4=.;
gen setenure5=.;
gen regR2=.;
gen regobs=.;

**************************;
* Baseline Specification *;
**************************;

foreach sec of numlist 2(1)13 {;
display "Industry is";
display `sec';
foreach occ of numlist 1(1)5 {;
display "Occupation is";
display `occ';

* Mincer regressions;
areg lwageyr `demog' `educ' tenure2-tenure5 if firm_subsibge==`sec'&occup==`occ', robust abs(cnpj_radic);

* Coefficients;
replace bchild=_b[indchild] if firm_subsibge==`sec'&occup==`occ';
replace byouth=_b[indyouth] if firm_subsibge==`sec'&occup==`occ';
replace badol=_b[indadol] if firm_subsibge==`sec'&occup==`occ';
replace bnasc=_b[indnasc] if firm_subsibge==`sec'&occup==`occ';
replace bearly=_b[indearly] if firm_subsibge==`sec'&occup==`occ';
replace bpeak=_b[indpeak] if firm_subsibge==`sec'&occup==`occ';
replace blate=_b[indlate] if firm_subsibge==`sec'&occup==`occ';
replace bretir=_b[indretir] if firm_subsibge==`sec'&occup==`occ';
replace bfem=_b[indfem] if firm_subsibge==`sec'&occup==`occ';
replace bhigh=_b[indhigh] if firm_subsibge==`sec'&occup==`occ';
replace bscoll=_b[indscoll] if firm_subsibge==`sec'&occup==`occ';
replace bgrad=_b[indgrad] if firm_subsibge==`sec'&occup==`occ';
replace btenure2=_b[tenure2] if firm_subsibge==`sec'&occup==`occ';
replace btenure3=_b[tenure3] if firm_subsibge==`sec'&occup==`occ';
replace btenure4=_b[tenure4] if firm_subsibge==`sec'&occup==`occ';
replace btenure5=_b[tenure5] if firm_subsibge==`sec'&occup==`occ';

replace sechild=_se[indchild] if firm_subsibge==`sec'&occup==`occ';
replace seyouth=_se[indyouth] if firm_subsibge==`sec'&occup==`occ';
replace seadol=_se[indadol] if firm_subsibge==`sec'&occup==`occ';
replace senasc=_se[indnasc] if firm_subsibge==`sec'&occup==`occ';
replace seearly=_se[indearly] if firm_subsibge==`sec'&occup==`occ';
replace sepeak=_se[indpeak] if firm_subsibge==`sec'&occup==`occ';
replace selate=_se[indlate] if firm_subsibge==`sec'&occup==`occ';
replace seretir=_se[indretir] if firm_subsibge==`sec'&occup==`occ';
replace sefem=_se[indfem] if firm_subsibge==`sec'&occup==`occ';
replace sehigh=_se[indhigh] if firm_subsibge==`sec'&occup==`occ';
replace sescoll=_se[indscoll] if firm_subsibge==`sec'&occup==`occ';
replace segrad=_se[indgrad] if firm_subsibge==`sec'&occup==`occ';
replace setenure2=_se[tenure2] if firm_subsibge==`sec'&occup==`occ';
replace setenure3=_se[tenure3] if firm_subsibge==`sec'&occup==`occ';
replace setenure4=_se[tenure4] if firm_subsibge==`sec'&occup==`occ';
replace setenure5=_se[tenure5] if firm_subsibge==`sec'&occup==`occ';

replace regR2=e(r2) if firm_subsibge==`sec'&occup==`occ';
replace regobs=e(N) if firm_subsibge==`sec'&occup==`occ';

* Residual wage inequality;
predict temp if e(sample), res;
replace reslwageyr=temp if firm_subsibge==`sec'&occup==`occ';
drop temp;
* Observables;
predict temp if e(sample), xb;
replace obslwageyr=temp if firm_subsibge==`sec'&occup==`occ';
drop temp;
* Time-varying firm fixed effects;
predict temp if e(sample), d;
replace felwageyr=temp if firm_subsibge==`sec'&occup==`occ';
drop temp; 

};
};

gen year=`yr';

********************;
* Save Worker Data *;
********************;

lab var reslwageyr 	"Worker residual log wage";
lab var obslwageyr 	"Worker observable component worker log wage";
lab var felwageyr 	"Worker firm time-varying fixed effect component";

so cnpj_radic firm_subsibge occup year pis;
order cnpj_radic firm_subsibge occup year pis;
sa $data/condwtvfe/mincer/workers-`yr'.dta,replace;

******************;
* Save Firm Data *;
******************;

local mnvbles1="lwageyr wageyr reslwageyr obslwageyr felwageyr firm_indexp forworker useujap";
local mnvbles2="bchild byouth badol bnasc bearly bpeak blate bretir bfem";
local mnvbles3="bhigh bscoll bgrad btenure2 btenure3 btenure4 btenure5";
local mnvbles4="sechild seyouth seadol senasc seearly sepeak selate seretir sefem";
local mnvbles5="sehigh sescoll segrad setenure2 setenure3 setenure4 setenure5";
local mnvbles6="regR2 regobs";

collapse (mean) `mnvbles1' `mnvbles2' `mnvbles3' `mnvbles4' `mnvbles5' `mnvbles6' (sum) employ 
, by(cnpj_radic firm_subsibge occup meso state year) fast;
order cnpj_radic firm_subsibge occup year lwageyr wageyr reslwageyr obslwageyr felwageyr firm_indexp employ meso state; 

lab var lwageyr 	"Firm mean of worker log wages";
lab var wageyr 		"Firm mean of worker wage";
lab var reslwageyr 	"Firm mean of worker residual log wage";
lab var obslwageyr 	"Firm mean of observable component worker log wage";
lab var felwageyr 	"Firm time-varying fixed effect";
lab var employ 		"Firm employment";
lab var firm_indexp 	"Indicator for whether a firm exports";
lab var forworker       "Fraction of firm's employees within an occupation that are foreign";
lab var useujap         "Fraction of a firm's employees within an occupation that are US/EU/JAP";

order cnpj_radic firm_subsibge occup year;
so cnpj_radic firm_subsibge occup year;
sa $data/condwtvfe/mincer/tmincer-`yr'.dta,replace;

log close;

};

******************************************;
**** Merge Mincer Firm Files Together ****;
******************************************;

#delimit;
clear;
u $data/condwtvfe/mincer/tmincer-1986.dta;
foreach yr of numlist 1987(1)1998 {;
append using $data/condwtvfe/mincer/tmincer-`yr'.dta;
};
so cnpj_radic firm_subsibge occup year;
sa $data/condwtvfe/mincer/tmincer-all.dta, replace;

*****************************************;
**** Merge Mincer and Funcex by year ****;
*****************************************;

#delimit;
foreach yr of numlist 1986(1)1998 {;
clear;
u $data/condwtvfe/mincer/tmincer-`yr'.dta;
drop firm_indexp;
so cnpj_radic year occup;
* Merge FUNCEX main data;
merge cnpj_radic year using $data/funcex/expimp-cnpjradic-clean-`yr'.dta;
tab _m;
keep if _m==1|_m==3;
drop _m;
replace indexp=0 if indexp==.;
replace indimp=0 if indimp==.;
* Merge FUNCEX USA data;
so cnpj_radic year occup;
merge cnpj_radic year using $data/funcex/exp-usa-cnpjradic-clean-`yr'.dta;
tab _m;
keep if _m==1|_m==3;
drop _m;
replace indexpusa=0 if indexpusa==.;
* Merge FUNCEX destinations plus data;
so cnpj_radic year occup;
merge cnpj_radic year using $data/funcex/exp-dest10pls-cnpjradic-clean-`yr'.dta;
tab _m;
keep if _m==1|_m==3;
drop _m;
replace ind10pls=0 if ind10pls==.;
* Merge FUNCEX all destinations data;
so cnpj_radic year occup;
merge cnpj_radic year using $data/funcex/exp-destbins-cnpjradic-clean-`yr'.dta;
tab _m;
keep if _m==1|_m==3;
drop _m;
replace indexp0001=0 if indexp0001==.;
replace indexp0105=0 if indexp0105==.;
replace indexp0510=0 if indexp0510==.;
replace indexp1015=0 if indexp1015==.;
replace indexp1520=0 if indexp1520==.;
replace indexp2025=0 if indexp2025==.;
replace indexp2530=0 if indexp2530==.;
replace indexp3040=0 if indexp3040==.;
replace indexp4050=0 if indexp4050==.;
replace indexp50=0 if indexp50==.;
* Save data;
so cnpj_radic firm_subsibge occup year;
sa $data/condwtvfe/mincer/tmincer-`yr'-fun.dta, replace;
};

#delimit;
clear;
u $data/condwtvfe/mincer/tmincer-all.dta;
drop firm_indexp;
so cnpj_radic year occup;
merge cnpj_radic year using $data/funcex/expimp-cnpjradic-clean.dta;
tab _m;
keep if _m==1|_m==3;
drop _m;
replace indexp=0 if indexp==.;
replace indimp=0 if indimp==.;
egen max_indimp=max(indimp),by(year);
replace indimp=. if max_indimp==0;
drop max_indimp;
so cnpj_radic firm_subsibge occup year;
sa $data/condwtvfe/mincer/tmincer-all-fun.dta, replace;

********************************************;
**** Merge Mincer Worker Files Together ****;
********************************************;

log using $logs/condwtvfe/mincer/descrip-sample-stats.log, replace; 

#delimit;
clear;
u /data/sjredding/condwtvfe/mincer/workers-1986.dta;
foreach yr of numlist 1987(1)1998 {;
append using /data/sjredding/condwtvfe/mincer/workers-`yr'.dta;
};
so cnpj_radic firm_subsibge occup year pis;
sa /data/sjredding/condwtvfe/mincer/workers-all.dta, replace;

* Descriptive statistics;

#delimit;
isid cnpj_radic firm_subsibge occup year pis;
gen data=1;
collapse (mean) data, by(pis);
su data;
clear;
u /data/sjredding/condwtvfe/mincer/workers-all.dta;
gen data=1;
collapse (mean) data, by(cnpj_radic);
su cnpj_radic;

log close;

