
#delimit;

*************************************************************************************;
**** Results of robustness test using firm-year rather than firm-occupation-year ****;
**** fixed effects                                                               ****;
*************************************************************************************;

clear;
clear matrix;
set mem 8000m;
set matsize 10000;
set more off;
capture log close;
set scheme s2mono;
capture log close;

global dofiles="/home/sjredding/himr-restud/stata/dofiles";
global logs="/home/sjredding/himr-restud/stata/logs";
global input="/data/sjredding/himr-input";
global data="/data/sjredding/himr-restud";

log using $logs/condwtvfe/tanova/tanalysis_firm.log,replace;

*******************************************************************;
**** Merge within-between decomposition and employment weights ****;              
*******************************************************************;

clear;
u $data/condwtvfe/tanova/twithinbetween-firm-all.dta;
so firm_subsibge year;
merge firm_subsibge year using $data/prepdata/emp-ind-all-wweights.dta;
drop _m;
keep if firm_subsibge>=2 &firm_subsibge<=13;
sort firm_subsibge year;

********************;
**** AGGREGATES ****;
********************;

replace ttot = weight * ttot;
replace tobs = weight * tobs;
replace tcov = weight * tcov;
replace tbetween = weight * tbetween;
replace tres = weight * tres;
replace tbetweenfirm = weight * tbetweenfirm;
replace tbetweenmeso = weight * tbetweenmeso; 

collapse (sum) ttot tobs tcov tbetween tres tbetweenfirm tbetweenmeso , by(year);

gen test=ttot-(tobs+tcov+tbetween+tres);
replace test=int(test*10000);
su test, d;
drop test;

gen test=tbetween-(tbetweenfirm+tbetweenmeso);
replace test=int(test*10000);
su test, d;
drop test;

**********************************************;
* Decomposition without exporter information *;
**********************************************;

foreach var of varlist ttot tobs tcov tbetween tres tbetweenfirm tbetweenmeso {;
gen temp=`var' if year==1986;
egen `var'86=max(temp);
drop temp;
gen i`var'=`var'-`var'86;
gen temp=`var' if year==1995;
egen `var'95=max(temp);
drop temp;
};   

**************************;
**** Tables for Paper ****;
**************************;

gen sh_obs=tobs/ttot;
gen sh_cov=tcov/ttot;
gen sh_between=tbetween/ttot;
gen sh_res=tres/ttot;

foreach var of varlist sh_obs sh_cov sh_between sh_res {; 
gen temp=`var' if year==1986;
egen `var'86=max(temp);
drop temp;
};

foreach var of varlist ttot tobs tcov tbetween tres {;
gen d_`var'86=(`var'95-`var'86)/`var'86;
};

gen cnt_obs86=(sh_obs86*d_tobs86)/d_ttot86;
gen cnt_cov86=(sh_cov86*d_tcov86)/d_ttot86;
gen cnt_between86=(sh_between86*d_tbetween86)/d_ttot86;
gen cnt_res86=(sh_res86*d_tres86)/d_ttot86;

gen data=1;

**** Robustness test for decomposition of wage inequality within sector-years;
**** into firm-year (rather than firm-occupation-year) fixed effects,;
**** worker observables, covariance and within-firm component;

**** Online Supplement, Section H13;
**** Decomposition of level of wage inequality within sectors in 1994;
**** sh_obs : share of worker observables;
**** sh_cov : share of covariance firm effects and worker observables;
**** sh_between : share of between-firm component;
**** sh_res : share of within-firm component;

format sh_obs sh_cov sh_between sh_res %10.3f;
table data if year==1994, c(mean sh_obs mean sh_between mean sh_cov mean sh_res);

**** Online Supplement, Section H13;
**** Decomposition of changes in wage inequality within sectors from 1986-95;
**** cnt_obs86 : contribution worker observables;
**** cnt_cov86 : contribution of covariance firm effects and worker observables;
**** cnt_between86 : contribution of between-firm component;
**** cnt_res86 : contribution of within-firm component;

* Observables Growth contributions 1986-1995;

format cnt_obs86 %10.3f;
table data if year==1995, c(mean cnt_obs86);

* Covariance Growth contributions 1986-1995;

format cnt_cov86 %10.3f;
table data if year==1995, c(mean cnt_cov86);

* Between-firm Growth contributions 1986-1995;

format cnt_between86 %10.3f;
table data if year==1995, c(mean cnt_between86);

* Residual Growth contributions 1986-1995;

format cnt_res86 %10.3f;
table data if year==1995, c(mean cnt_res86);

log close;


