

#delimit;

************************************************************************************;
**** Robustness test by sector with results of decomposition of wage inequality ****;
**** within sector-occupation-years into within and between-firm                ****;
**** components                                                                 ****;
************************************************************************************;

clear;
clear matrix;
set mem 8000m;
set matsize 10000;
set more off;
capture log close;
set scheme s2mono;
capture log close;

global dofiles="/home/sjredding/himr-restud/stata/dofiles";
global logs="/home/sjredding/himr-restud/stata/logs";
global tables="/home/sjredding/himr-restud/stata/tables";
global input="/data/sjredding/himr-input";
global data="/data/sjredding/himr-restud";

log using $logs/condwtvfe/tanova/tanalysis_sector.log,replace;

*******************************************************************;
**** Merge within-between decomposition and employment weights ****;               
*******************************************************************;

clear;
u $data/condwtvfe/tanova/twithinbetween-all.dta;
so firm_subsibge occup year;
merge firm_subsibge occup year using $data/prepdata/emp-ind-occup-all-wweights.dta;
tab _m;
drop _m;
sort firm_subsibge occup year;

******************************;
**** AGGREGATES BY SECTOR ****;
******************************;

replace ttot = weight_industry * ttot;
replace tobs = weight_industry * tobs;
replace tcov = weight_industry * tcov;
replace tbetween = weight_industry * tbetween;
replace tres = weight_industry * tres;
replace tbetweenfirm = weight_industry * tbetweenfirm;
replace tbetweenmeso = weight_industry * tbetweenmeso; 

collapse (sum) ttot tobs tcov tbetween tres tbetweenfirm tbetweenmeso , by(firm_subsibge year) fast;

gen test=ttot-(tobs+tcov+tbetween+tres);
replace test=int(test*10000);
su test, d;
drop test;

gen test=tbetween-(tbetweenfirm+tbetweenmeso);
replace test=int(test*10000);
su test, d;
drop test;

**********************************************;
* Decomposition without exporter information *;
**********************************************;

foreach var of varlist ttot tobs tcov tbetween tres tbetweenfirm tbetweenmeso {;
gen temp=`var' if year==1986;
egen `var'86=max(temp),by(firm_subsibge);
drop temp;
gen i`var'=`var'-`var'86;
gen temp=`var' if year==1995;
egen `var'95=max(temp),by(firm_subsibge);
drop temp;
};   

**************************;
**** Tables for Paper ****;
**************************;

gen sh_obs=tobs/ttot;
gen sh_cov=tcov/ttot;
gen sh_between=tbetween/ttot;
gen sh_res=tres/ttot;

foreach var of varlist sh_obs sh_cov sh_between sh_res {; 
gen temp=`var' if year==1986;
egen `var'86=max(temp),by(firm_subsibge);
drop temp;
};

foreach var of varlist ttot tobs tcov tbetween tres {;
gen d_`var'86=(`var'95-`var'86)/`var'86;
};

gen cnt_obs86=(sh_obs86*d_tobs86)/d_ttot86;
gen cnt_cov86=(sh_cov86*d_tcov86)/d_ttot86;
gen cnt_between86=(sh_between86*d_tbetween86)/d_ttot86;
gen cnt_res86=(sh_res86*d_tres86)/d_ttot86;

gen data=1;

**** Robustness test for decomposing the level of wage inequality in 1994;
**** Table H6 of the online supplement (by sector);
**** sh_between : is share of between-firm component;
**** sh_res : is share of within-firm component;
**** sh_obs : is share of worker observables;
**** sh_cov : is share of covariance;

format sh_between sh_res sh_obs sh_cov  %10.3f;
outsheet firm_subsibge year sh_between sh_res sh_obs sh_cov if year==1994 using $tables/tanova-sector-level-within-between-1994.csv, comma replace names;

log close;


