#delimit;

clear;
clear matrix;
set more off;

capture log close; 
log using $logs/soanalysis_ramo.log, replace;

*******************************;
**** Read in and Save Data ****;
*******************************;

u $data/pnad/sector-occupation/withinbetween-1995-alt.dta, clear;
foreach year of numlist 1996(1)1998 {;
append using $data/pnad/sector-occupation/withinbetween-`year'-alt.dta;
};

lab var swithin "within sectors log wage component";
lab var sbetween "between sectors log wage component";
lab var stotal "total log wage component (across sectors)";

lab var owithin "within occupations log wage component";
lab var obetween "between occupations log wage component";
lab var ototal "total log wage component (across occupations)";

lab var sowithin "within sector-occupations log wage component";
lab var sobetween "between sector-occupations log wage component";
lab var sototal "total log wage component (across sector-occupations)";

order year swithin sbetween stotal owithin obetween ototal sowithin sobetween sototal;
sort year;
sa $data/pnad/sector-occupation/withinbetween-all-alt.dta, replace;

*************************;
**** Analyze Results ****;
*************************;

gen stest=swithin+sbetween;
replace stest=stest-stotal;
replace stest=int(stest*10000);

gen otest=owithin+obetween;
replace otest=otest-ototal;
replace otest=int(otest*10000);

gen sotest=sowithin+sobetween;
replace sotest=sotest-sototal;
replace sotest=int(sotest*10000);

su stest otest sotest;
drop stest otest sotest;

foreach var of varlist swithin sbetween stotal owithin obetween ototal sowithin sobetween sototal {;
gen temp=`var' if year==1995;
egen `var'95=max(temp);
drop temp;
gen i`var'=`var'-`var'95;
gen temp=`var' if year==1998;
egen `var'98=max(temp);
drop temp;
};   

**************************;
**** Tables for Paper ****;
**************************;

gen data=1;

gen sh_swithin=swithin/stotal;
gen sh_owithin=owithin/ototal;
gen sh_sowithin=sowithin/sototal;

foreach var of varlist swithin sbetween stotal owithin obetween ototal sowithin sobetween sototal {;
gen d_`var'=(`var'98-`var'95)/`var'95; 
};

gen wgt_swithin=swithin95/stotal95;
gen wgt_owithin=owithin95/ototal95;
gen wgt_sowithin=sowithin95/sototal95;

gen cnt_swithin=(wgt_swithin*d_swithin)/d_stotal;
gen cnt_owithin=(wgt_owithin*d_owithin)/d_ototal;
gen cnt_sowithin=(wgt_sowithin*d_sowithin)/d_sototal;

* Level within contributions in 1995;

format sh_swithin sh_owithin sh_sowithin %10.3f;
table data if year==1995, c(mean sh_swithin mean sh_owithin mean sh_sowithin);

* Sector contributions 1995-1998;

format d_stotal cnt_swithin wgt_swithin d_swithin d_sbetween %10.3f;
table data if year==1995, c(mean d_stotal mean cnt_swithin mean wgt_swithin mean d_swithin mean d_sbetween);

* Occupation contributions 1995-1998;

format d_ototal cnt_owithin wgt_owithin d_owithin d_obetween %10.3f;
table data if year==1995, c(mean d_ototal mean cnt_owithin mean wgt_owithin mean d_owithin mean d_obetween);

* Sector-occupation contributions 1995-1998;

format d_sototal cnt_sowithin wgt_sowithin d_sowithin d_sobetween %10.3f;
table data if year==1995, c(mean d_sototal mean cnt_sowithin mean wgt_sowithin mean d_sowithin mean d_sobetween);

**********************************;
**** Figures for presentation ****;
**********************************;

* Levels;

twoway 
(scatter stotal year , msymbol(i) c(l) lpattern(solid) lcolor(black) lwidth(thick))
(scatter swithin year , msymbol(i) c(l) lpattern(solid) lcolor(blue) lwidth(thick))
(scatter owithin year , msymbol(i) c(l) lpattern(solid) lcolor(red) lwidth(thick))
(scatter sowithin year , msymbol(i) c(l) lpattern(solid) lcolor(green) lwidth(thick))
,
graphregion(fcolor(gs16))
legend(lab(1 "Total") lab(2 "Within Sector") lab(3 "Within Occupation") lab(4 "Within Sector-Occupation"))
xlabel(1995 1998)
xtitle(Year)
ytitle(St. deviation log wage)
note("Note: using detailed occupations (>300) and detailed sectors (>250)")
saving($grph/sector-occupation/uncond_level_all_alt,replace)
;

twoway 
(scatter istotal year , msymbol(i) c(l) lpattern(solid) lcolor(black) lwidth(thick))
(scatter iswithin year , msymbol(i) c(l) lpattern(solid) lcolor(red) lwidth(thick))
(scatter isbetween year , msymbol(i) c(l) lpattern(solid) lcolor(blue) lwidth(thick))
,
graphregion(fcolor(gs16))
legend(lab(1 "Total") lab(2 "Within sector") lab(3 "Between sector"))
xlabel(1995 1998)
xtitle(Year)
ytitle(Index (1986=0))
title(Sectors)
saving($grph/sector-occupation/u-i-sector-alt,replace)
;

twoway (scatter iototal year , msymbol(i) c(l) lpattern(solid) lcolor(black) lwidth(thick))
(scatter iowithin year , msymbol(i) c(l) lpattern(solid) lcolor(red) lwidth(thick))
(scatter iobetween year , msymbol(i) c(l) lpattern(solid) lcolor(blue) lwidth(thick))
,
graphregion(fcolor(gs16))
legend(lab(1 "Total") lab(2 "Within occupation") lab(3 "Between occupation"))
xlabel(1995 1998)
xtitle(Year)
ytitle(Index (1986=0))
title(Occupations)
saving($grph/sector-occupation/u-i-occupation-alt,replace)
;

twoway (scatter isototal year , msymbol(i) c(l) lpattern(solid) lcolor(black) lwidth(thick))
(scatter isowithin year , msymbol(i) c(l) lpattern(solid) lcolor(red) lwidth(thick))
(scatter isobetween year , msymbol(i) c(l) lpattern(solid) lcolor(blue) lwidth(thick))
,
graphregion(fcolor(gs16))
legend(lab(1 "Total") lab(2 "Within sector-occupation") lab(3 "Between sector-occupation"))
xlabel(1995 1998)
xtitle(Year)
ytitle(Index (1986=0))
title(Sector-Occupations)
saving($grph/sector-occupation/u-i-sectoroccupation-alt,replace)
;

gr combine "$grph/sector-occupation/u-i-sector-alt.gph"
"$grph/sector-occupation/u-i-occupation-alt.gph"
"$grph/sector-occupation/u-i-sectoroccupation-alt.gph",
graphregion(fcolor(gs16))
iscale(0.4)
title(Decomposition of Changes in Wage Inequality)
note("Note: using detailed occupations (>300) and detailed sectors (>250)")
saving($grph/sector-occupation/u-i-so-all-alt,replace)
;

log close;
