#delimit;

clear;
clear matrix;
set more off;
capture log close; 

log using $logs/soanova.log, replace;

******************************************;
* Loop to Undertake Analysis of Variance *;
******************************************;

foreach year of numlist 1986(1)1990 1992(1)1993 1995(1)1998 {;

use $input/pnad`year'pes_comp81_likerais.dta, clear;

* Define sample;

do $dofiles/routines/pnad-samplecond.do;

***************;
**** Setup ****;
***************;

* Demographics variables;
local demog="indchild indyouth indadol indnasc indearly indpeak indlate indretir indfem";

* Schooling variables;
local educ="indhigh indscoll indgrad";

* Basic occupation variables;
local occup="indprof indtech indwhit indsklb indunsklb";

egen secoccup = group(firm_subsibge occup);
egen soo = group(firm_subsibge cbogrp);

* Descriptives;

codebook firm_subsibge;
codebook occup;
codebook cbogrp;
codebook secoccup;
codebook soo;

***************************;
* Variance Decompositions *;
***************************;

* within/between decomposition for sectors;
areg lwageyr, abs(firm_subsibge);
predict fswithin if e(sample), res;
predict fsbetween if e(sample), xbd;
egen temp=sd(fsbetween);
gen sbetween = temp*temp;
drop temp;
egen temp=sd(fswithin);
gen swithin = temp*temp;
drop temp;
gen stotal = swithin + sbetween;

* within/between decomposition for occupations;
areg lwageyr, abs(occup);
predict fowithin if e(sample), res;
predict fobetween if e(sample), xbd;
egen temp=sd(fobetween);
gen obetween = temp*temp;
drop temp;
egen temp=sd(fowithin);
gen owithin = temp*temp;
drop temp;
gen ototal = owithin + obetween;

* Within/between decomposition for sector-occupations;
areg lwageyr, abs(secoccup);
predict fsowithin if e(sample), res;
predict fsobetween if e(sample), xbd;
egen temp=sd(fsobetween);
gen sobetween = temp*temp;
drop temp;
egen temp=sd(fsowithin);
gen sowithin = temp*temp;
drop temp;
gen sototal = sowithin + sobetween;

* Within/between decomposition for detailed occupations;
areg lwageyr, abs(cbogrp);
predict foowithin if e(sample), res;
predict foobetween if e(sample), xbd;
egen temp=sd(foobetween);
gen oobetween = temp*temp;
drop temp;
egen temp=sd(foowithin);
gen oowithin = temp*temp;
drop temp;
gen oototal = oowithin + oobetween;

* Within/between decomposition for sector-detailed-occupations;
areg lwageyr, abs(soo);
predict fsoowithin if e(sample), res;
predict fsoobetween if e(sample), xbd;
egen temp=sd(fsoobetween);
gen soobetween = temp*temp;
drop temp;
egen temp=sd(fsoowithin);
gen soowithin = temp*temp;
drop temp;
gen soototal = soowithin + soobetween;

****************;
* Polarization *;
****************;

foreach var of varlist lwageyr fswithin fsbetween fowithin fobetween fsowithin fsobetween {;
egen p90`var'=pctile(`var'), p(90);
egen p50`var'=pctile(`var'), p(50);
egen p10`var'=pctile(`var'), p(10);
gen `var'9050=p90`var'-p50`var';
gen `var'5010=p50`var'-p10`var';
};

*************;
* Save Data *;
*************;

collapse (mean) swithin sbetween stotal owithin obetween ototal sowithin sobetween sototal
oowithin oobetween oototal soowithin soobetween soototal
lwageyr9050 fswithin9050 fsbetween9050 fowithin9050 fobetween9050 fsowithin9050 fsobetween9050
lwageyr5010 fswithin5010 fsbetween5010 fowithin5010 fobetween5010 fsowithin5010 fsobetween5010, fast;

gen year=`year';

sa $data/pnad/sector-occupation/withinbetween-`year'.dta, replace;

};

log close;



