
#delimit;

clear;
clear matrix;
set mem 4000m;
set matsize 10000;
set more off;
capture log close;
graph set print logo off;

global dofiles="/home/sjredding/himr-restud/stata/dofiles";
global logs="/home/sjredding/himr-restud/stata/logs";
global input="/data/sjredding/himr-input";
global data="/data/sjredding/himr-restud";

*********************************************************;
**** This file cleans up the trade transactions data ****;
*********************************************************;

************************************;
**** Clean new FUNCEX firm data ****;
************************************;

clear;
u $input/expimp-cnpjradic.dta;
ren ano year;
so cnpj_radic year;
sa $data/funcex/expimp-cnpjradic-clean.dta, replace;

foreach yr of numlist 1986(1)1998 {;
clear;
u $data/funcex/expimp-cnpjradic-clean.dta;
keep if year==`yr';
so cnpj_radic year;
sa $data/funcex/expimp-cnpjradic-clean-`yr'.dta, replace;
};

***********************************;
**** Clean new FUNCEX USA data ****;
***********************************;

#delimit;
clear;
u $input/exp-usa-cnpjradic.dta;
ren indus indexpusa;
so cnpj_radic year;
sa $data/funcex/exp-usa-cnpjradic-clean.dta, replace;

foreach yr of numlist 1986(1)1998 {;
clear;
u $data/funcex/exp-usa-cnpjradic-clean.dta;
keep if year==`yr';
so cnpj_radic year;
sa $data/funcex/exp-usa-cnpjradic-clean-`yr'.dta, replace;
};

*************************************************;
**** Clean new FUNCEX destinations plus data ****;
*************************************************;

* Export to EU;
* exp-weu-cnpjradic.dta;
* Export to Destinations plus;
* exp-dest`c'pls-cnpjradic.dta;
* Export quartiles;
* exp-destquart-cnpjradic.dta;

#delimit;
clear;
u $input/exp-dest10pls-cnpjradic.dta;
so cnpj_radic year;
sa $data/funcex/exp-dest10pls-cnpjradic-clean.dta, replace;

foreach yr of numlist 1986(1)1998 {;
clear;
u $data/funcex/exp-dest10pls-cnpjradic-clean.dta;
keep if year==`yr';
so cnpj_radic year;
sa $data/funcex/exp-dest10pls-cnpjradic-clean-`yr'.dta, replace;
};

***************************************************;
**** Clean additional FUNCEX destinations data ****;
***************************************************;

/*;
**** destbin is defined as follows;
* Dest: 1 		1
* Dest: >1 & <=5 	2
* Dest: >5 & <=10 	3
* Dest: >10 & <=15 	4
* Dest: >15 & <=20 	5
* Dest: >20 & <=25 	6
* Dest: >25 & <=30 	7
* Dest: >30 & <=40 	8
* Dest: >40 & <=50 	9
* Dest: >50 		10
*/;

clear;
u $input/exp-cnpjradic-destbins.dta;

gen indexp0001=0;
replace indexp0001=1 if destbin==1;

gen indexp0105=0;
replace indexp0105=1 if destbin==2;

gen indexp0510=0;
replace indexp0510=1 if destbin==3;

gen indexp1015=0;
replace indexp1015=1 if destbin==4;

gen indexp1520=0;
replace indexp1520=1 if destbin==5;

gen indexp2025=0;
replace indexp2025=1 if destbin==6;

gen indexp2530=0;
replace indexp2530=1 if destbin==7;

gen indexp3040=0;
replace indexp3040=1 if destbin==8;

gen indexp4050=0;
replace indexp4050=1 if destbin==9;

gen indexp50=0;
replace indexp50=1 if destbin==10;

drop if year>1998;

so cnpj_radic year;
sa $data/funcex/exp-destbins-cnpjradic-clean-all.dta, replace;

* Create datasets by year;

foreach yr of numlist 1986(1)1998 {;
u $data/funcex/exp-destbins-cnpjradic-clean-all.dta, clear;
keep if year==`yr';
so cnpj_radic year;
sa $data/funcex/exp-destbins-cnpjradic-clean-`yr'.dta, replace;
};
