
#delimit;

****************************************************************************************;
**** Constructs a robustness sample including manufacturing, mining and agriculture ****;
****************************************************************************************;

display "Starting sample";
su pis;

/*;
1 `"Mining and quarrying"'
2 `"Manufacture of non-metallic mineral products"'
3 `"Manufacture of metallic products"'
4 `"Manufacture of machinery, equipment and instruments"'
5 `"Manufacture of electrical and telecommunications equipment"'
6 `"Manufacture of transport equipment"'
7 `"Manufacture of wood products and furniture"'
8 `"Manufacture of paper and paperboard, and publishing and printing"'
9 `"Manufacture of rubber, tobacco, leather and fur, and manufacturing n.e.c."'
10 `"Manufacture of chemical and pharmaceutical products"'
11 `"Manufacture of apparel and textiles"'
12 `"Manufacture of footwear"'
13 `"Manufacture of food, beverages, and ethyl alcohol"'
14 `"Electricity, gas and water supply"'
15 `"Construction"'
16 `"Retail trade"'
17 `"Wholesale trade"'
18 `"Financial intermediation and insurance"'
19 `"Real estate and business services"'
20 `"Transport, storage and telecommunications"'
21 `"Hotels and restaurants, repair and maintenance services"'
22 `"Medical, dental and veterinary services"'
23 `"Education"'
24 `"Public administration and social services"'
25 `"Agriculture, farming, hunting, forestry and fishing"'
26 `"Activities n.e.c."'
*/;

display "(firm_subsibge>=1&firm_subsibge<=13)|firm_subsibge==25";
gen selectsample=0;
replace selectsample=1 if firm_subsibge>=1&firm_subsibge<=13;
replace selectsample=1 if firm_subsibge==25;
keep if selectsample==1;
drop selectsample;
su pis;

* Drop observations with missing firm_subsibge code;
display "Drop missing firm_subsibge code";
display "drop if firm_subsibge==.";
drop if firm_subsibge==.;
su pis;

* DEFINE SAMPLE;

display "Drop missing wage information";
display "drop if wageyr<=0";
display "drop if wageyr==.";
drop if wageyr<=0;
drop if wageyr==.;
su pis;

* Keep highest wage for each worker if more than one wage;
display "Keep highest wage for each worker if more than one wage";
gsort pis -wageyr;
quietly by pis: gen order=_n;
tab order;
drop if order>1;
drop order;
gen worker=_n;
su pis;

* Define variables;

gen lwageyr=ln(wageyr);
gen employ=1;

* Define occupations;

gen occup=.;
replace occup=1 if indprof==1;
replace occup=2 if indtech==1;
replace occup=3 if indwhit==1;
replace occup=4 if indsklb==1;
replace occup=5 if indunsklb==1;

display "Drop if occupation missing";
drop if occup==.;
su pis;

* Drop based on observables in Mincer regression;

display "Drop based on worker observables";
drop if indchild==.;
drop if indyouth==.;
drop if indadol==.;
drop if indnasc==.;
drop if indearly==.;
drop if indpeak==.;
drop if indlate==.;
drop if indretir==.;
drop if indfem==.;

drop if indhigh==.;
drop if indscoll==.;
drop if indgrad==.;

drop if indprof==.;
drop if indtech==.;
drop if indwhit==.;
drop if indsklb==.;
drop if indunsklb==.;

drop if temp_empr==.;
su pis;

* Drop data for small firms with less than five employees;
display "Drop data for small firms with less than five employees";
egen firm_emp=count(employ), by(cnpj_radic);
drop if firm_emp<5;
su pis;

so cnpj_radic pis;
