
#delimit;

clear;
clear matrix;
set mem 8000m;
set matsize 10000;
set more off;
capture log close;
set scheme s1mono;

global dofiles="/home/sjredding/himr-restud/stata/dofiles";
global logs="/home/sjredding/himr-restud/stata/logs";
global graphs="/home/sjredding/himr-restud/stata/graphs";
global input="/data/sjredding/himr-input";
global data="/data/sjredding/himr-restud";

****************************************************************************************;
**** This file undertakes the decompositions of residual wage inequality            ****;
**** into within and between sector-occupation components for Table 1 in the paper  ****;                                       ****;
****************************************************************************************;

log using $logs/sector-occupation/csoanalysis.log, replace;

*******************************;
**** Read in and Save Data ****;
*******************************;

u $data/sector-occupation/c-withinbetween-1986.dta, clear;
foreach yr of numlist 1987(1)1998 {;
append using $data/sector-occupation/c-withinbetween-`yr'.dta;
};

lab var wgedisp 	"overall wage dispersion";
lab var obsdisp 	"wage dispersion explained by observables";

lab var swithin 	"within sectors conditional log wage component";
lab var sbetween 	"between sectors conditional log wage component";
lab var scond 		"conditional log wage component (across sectors)";

lab var owithin 	"within occupations conditional log wage component";
lab var obetween 	"between occupations conditional log wage component";
lab var ocond 		"conditional log wage component (across occupations)";

lab var sowithin 	"within sector-occupations conditional log wage component";
lab var sobetween 	"between sector-occupations conditional log wage component";
lab var socond 		"conditional log wage component (across sector-occupations)";

lab var oowithin 	"within detailed occupations log wage component";
lab var oobetween 	"between detailed occupations log wage component";
lab var oocond	 	"total log wage component (across detailed occupations)";

lab var soowithin 	"within sector-detailed-occupations log wage component";
lab var soobetween 	"between sector-detailed-occupations log wage component";
lab var soocond 	"total log wage component (across sector-detailed-occupations)";

local outvar="wgedisp obsdisp swithin sbetween scond owithin obetween ocond sowithin sobetween socond";

order year wgedisp obsdisp swithin sbetween scond owithin obetween ocond sowithin sobetween socond;
sort year;
sa $data/sector-occupation/c-withinbetween-all.dta, replace;

****************************;
**** Use Mincer results ****;
****************************;

* Outsheet coefficients data for Excel table;

local vbles="b_indchild b_indyouth b_indadol b_indnasc b_indearly b_indpeak b_indlate b_indretir b_indfem b_indhigh b_indscoll b_indgrad b_tenure2 b_tenure3 b_tenure4 b_tenure5";
outsheet year `vbles' using $data/sector-occupation/cso-mincer-coeff-results-year.csv, comma replace names nolabel;
local sbles="se_indchild se_indyouth se_indadol se_indnasc se_indearly se_indpeak se_indlate se_indretir se_indfem se_indhigh se_indscoll se_indgrad se_tenure2 se_tenure3 se_tenure4 se_tenure5 regR2 regobs";
outsheet year `sbles' using $data/sector-occupation/cso-mincer-se-results-year.csv, comma replace names nolabel;

*************************************************;
**** Figure H5 for Online Supplement         ****;
**** Analyze Change in Return to Education   ****;
*************************************************;

clear;
u $data/sector-occupation/c-withinbetween-all.dta;

gen b_prim=0;
keep year b_prim b_indhigh b_indscoll b_indgrad;
ren b_prim educ1;
ren b_indhigh educ2;
ren b_indscoll educ3;
ren b_indgrad educ4;

reshape long educ , i(year) j(elevel);

lab def elevel 1 "Primary" 2 "High" 3 "Some College" 4 "College";
lab val elevel elevel;

twoway (scatter educ elevel if year==1986 , c(l) msymbol(O) lpattern(solid) lcolor(black) lwidth(thick))
(scatter educ elevel if year==1994 , c(l) msymbol(Oh) lpattern(solid) lcolor(gs12) lwidth(thick))
(scatter educ elevel if year==1998 , c(l) msymbol(X) lpattern(dash) lcolor(gs12) lwidth(thick))
,
graphregion(fcolor(gs16)) 
ytitle(Coeff. Log Wage Regression)
xtitle(Education Level)
xlabel(1 2 3 4, valuelabel)
legend(lab(1 "1986") lab(2 "1994") lab(3 "1998"))
title(Returns to Education Over Time)
;

graph bar educ if (year==1986|year==1990|year==1994|year==1998)&elevel==2 
, over(year) ylabel(0.25 0.5 0.75 1 1.25 1.5)
title(Panel A: High School) ytitle(Estimated Coefficient) saving($graphs/sector-occupation/educ2,replace);
graph bar educ if (year==1986|year==1990|year==1994|year==1998)&elevel==3 
, over(year) ylabel(0.25 0.5 0.75 1 1.25 1.5)
title(Panel B: Some College) ytitle(Estimated Coefficient) saving($graphs/sector-occupation/educ3,replace);
graph bar educ if (year==1986|year==1990|year==1994|year==1998)&elevel==4 
, over(year)  ylabel(0.25 0.5 0.75 1 1.25 1.5)
title(Panel C: College Graduate) ytitle(Estimated Coefficient) saving($graphs/sector-occupation/educ4,replace);

gr combine "$graphs/sector-occupation/educ2.gph"
"$graphs/sector-occupation/educ3.gph"
"$graphs/sector-occupation/educ4.gph"
,
iscale(0.5)
saving($graphs/sector-occupation/educreturns,replace)
; 

graph export $graphs/sector-occupation/educreturns.eps, as(eps) replace;

*************************************************;
**** Figure H6 for Online Supplement         ****;
**** Analyze Change in Return to Tenure      ****;
*************************************************;

u $data/sector-occupation/c-withinbetween-all.dta, clear;

gen b_tenure1=0;
keep year b_tenure1 b_tenure2 b_tenure3 b_tenure4 b_tenure5;

reshape long b_tenure , i(year) j(tlevel);

lab def tlevel 1 "Quintile 1" 2 "Quintile 2" 3 "Quintile 3" 4 "Quintile 4" 5 "Quintile 5";
lab val tlevel tlevel;

twoway (scatter b_tenure tlevel if year==1986 , c(l) msymbol(O) lpattern(solid) lcolor(black) lwidth(thick))
(scatter b_tenure tlevel if year==1994 , c(l) msymbol(Oh) lpattern(solid) lcolor(gs12) lwidth(thick))
(scatter b_tenure tlevel if year==1998 , c(l) msymbol(X) lpattern(dash) lcolor(gs12) lwidth(thick))
,
graphregion(fcolor(gs16)) 
ytitle(Coeff. Log Wage Regression)
xtitle(Tenure Level)
xlabel(1 2 3 4 5, valuelabel)
legend(lab(1 "1986") lab(2 "1994") lab(3 "1998"))
title(Returns to Tenure Over Time)
;

graph bar b_tenure if (year==1986|year==1990|year==1994|year==1998)&tlevel==2 
, over(year) ylabel(0.2 0.4 0.6 0.8) 
title(Panel A: Second Quintile) ytitle(Estimated Coefficient) saving($graphs/sector-occupation/tenure2,replace);
graph bar b_tenure if (year==1986|year==1990|year==1994|year==1998)&tlevel==3 
, over(year) ylabel(0.2 0.4 0.6 0.8)
title(Panel B: Third Quintile) ytitle(Estimated Coefficient) saving($graphs/sector-occupation/tenure3,replace);
graph bar b_tenure if (year==1986|year==1990|year==1994|year==1998)&tlevel==4 
, over(year) ylabel(0.2 0.4 0.6 0.8)
title(Panel C: Fourth Quintile) ytitle(Estimated Coefficient) saving($graphs/sector-occupation/tenure4,replace);
graph bar b_tenure if (year==1986|year==1990|year==1994|year==1998)&tlevel==5 
, over(year) ylabel(0.2 0.4 0.6 0.8)
title(Panel D: Fifth Quintile) ytitle(Estimated Coefficient) saving($graphs/sector-occupation/tenure5,replace);

gr combine "$graphs/sector-occupation/tenure2.gph"
"$graphs/sector-occupation/tenure3.gph"
"$graphs/sector-occupation/tenure4.gph"
"$graphs/sector-occupation/tenure5.gph"
,
iscale(0.5)
saving($graphs/sector-occupation/tenurereturns,replace)
; 

graph export $graphs/sector-occupation/tenurereturns.eps, as(eps) replace;

*************************;
**** Analyze Results ****;
*************************;

u $data/sector-occupation/c-withinbetween-all.dta, clear;

gen stest=swithin+sbetween;
replace stest=stest-scond;
replace stest=int(stest*10000);

gen otest=owithin+obetween;
replace otest=otest-ocond;
replace otest=int(otest*10000);

gen sotest=sowithin+sobetween;
replace sotest=sotest-socond;
replace sotest=int(sotest*10000);

su stest otest sotest;
drop stest otest sotest;

foreach var of varlist wgedisp obsdisp swithin sbetween scond owithin obetween ocond sowithin sobetween socond oowithin oobetween oocond soowithin soobetween soocond {;
gen temp=`var' if year==1986;
egen `var'86=max(temp);
drop temp;
gen i`var'=`var'-`var'86;
gen temp=`var' if year==1995;
egen `var'95=max(temp);
drop temp;
gen temp=`var' if year==1994;
egen `var'94=max(temp);
drop temp;
gen temp=`var' if year==1998;
egen `var'98=max(temp);
drop temp;
gen ii`var'=`var'98-`var'94;
};   

gen data=1;

**********************************************************************;
**** Share of Residual Wage Inequality in Overall Wage Inequality ****;
**********************************************************************;

gen ash_sobs=obsdisp/wgedisp;
gen ash_swth=scond/wgedisp;

* Observables contribution in each year;
list year ash_sobs ash_swth;

foreach var of varlist ash_sobs ash_swth {;
gen temp=`var' if year==1986;
egen `var'86=max(temp);
drop temp;
};

foreach var of varlist wgedisp obsdisp scond {;
gen d_`var'86=(`var'95-`var'86)/`var'86; 
gen d_`var'94=(`var'98-`var'94)/`var'94; 
};

gen cnt_sobs86=(ash_sobs86*d_obsdisp86)/d_wgedisp86;
gen cnt_swth86=(ash_swth86*d_scond86)/d_wgedisp86;

**** Table 1 : Column (1), row (7), residual share of level of overall wage inequality 1994;

format ash_swth %10.4f;
table data if year==1994, c(mean ash_swth);

**** Table 1 : Column (2), row (7), residual share of changes in overall wage inequality 1986-95;

format cnt_swth86 %10.4f;
table data if year==1995, c(mean cnt_swth86);

****************************************************************************;
**** Share of Residual Wage Inequality that is Within-sector-occupation ****;
****************************************************************************;

gen sh_swithin=swithin/scond;
gen sh_owithin=owithin/ocond;
gen sh_sowithin=sowithin/socond;
gen sh_oowithin=oowithin/oocond;
gen sh_soowithin=soowithin/soocond;

foreach var of varlist sh_swithin sh_owithin sh_sowithin sh_oowithin sh_soowithin {;
gen temp=`var' if year==1986;
egen `var'86=max(temp);
drop temp;
gen temp=`var' if year==1994;
egen `var'94=max(temp);
drop temp;
};

foreach var of varlist swithin sbetween owithin obetween ocond sowithin sobetween socond oowithin oobetween oocond soowithin soobetween soocond {;
gen d_`var'86=(`var'95-`var'86)/`var'86; 
gen d_`var'94=(`var'98-`var'94)/`var'94; 
};

gen cnt_swithin86=(sh_swithin86*d_swithin86)/d_scond86;
gen cnt_owithin86=(sh_owithin86*d_owithin86)/d_ocond86;
gen cnt_sowithin86=(sh_sowithin86*d_sowithin86)/d_socond86;
gen cnt_oowithin86=(sh_oowithin86*d_oowithin86)/d_oocond86;
gen cnt_soowithin86=(sh_soowithin86*d_soowithin86)/d_soocond86;

gen cnt_swithin94=(sh_swithin94*d_swithin94)/d_scond94;
gen cnt_owithin94=(sh_owithin94*d_owithin94)/d_ocond94;
gen cnt_sowithin94=(sh_sowithin94*d_sowithin94)/d_socond94;
gen cnt_oowithin94=(sh_oowithin94*d_oowithin94)/d_oocond94;
gen cnt_soowithin94=(sh_soowithin94*d_soowithin94)/d_soocond94;

**** Table 1 : Column (1), row (8), share of level residual wage inequality that is within sector-occupation 1994;

format sh_sowithin %10.3f;
table data if year==1994, c(mean sh_sowithin);

**** Table 1 : Column (2), row (8), share of changes in residual wage inequality that is within sector-occupation 1986-95;

format cnt_sowithin86 %10.3f;
table data if year==1995, c(mean cnt_sowithin86);

*********************************************;
**** Figure H4 for the Online Supplement ****;
*********************************************;

* Observables and within-group;

twoway(scatter iwgedisp year , msymbol(i) c(l) lpattern(solid) lcolor(black) lwidth(thick))
(scatter iobsdisp year , msymbol(i) c(l) lpattern(solid) lcolor(orange) lwidth(medium))
(scatter iscond year , msymbol(i) c(l) lpattern(dash) lcolor(green) lwidth(thick))
,
graphregion(fcolor(gs16))
legend(lab(1 "Total") lab(2 "Observables") lab(3 "Residual"))
xlabel(1986 1990 1994 1998)
ylabel(0 0.02 0.04 0.06 0.08 0.1 0.12)
xtitle(Year)
ytitle(Index (1986=0))
title("Panel A: Observables and Residual Inequality", size(medlarge))
saving($graphs/sector-occupation/c-i-rawobs,replace)
;

graph export $graphs/sector-occupation/c-i-rawobs.eps, as(eps) replace;

* Within-group sectors;

twoway 
(scatter iscond year, msymbol(i) c(l) lpattern(solid) lcolor(black) lwidth(thick))
(scatter iswithin year , msymbol(i) c(l) lpattern(solid) lcolor(red) lwidth(thick))
(scatter isbetween year , msymbol(i) c(l) lpattern(solid) lcolor(blue) lwidth(thick))
,
graphregion(fcolor(gs16))
legend(lab(1 "Overall") lab(2 "Within Sector") lab(3 "Between Sector"))
xlabel(1986 1990 1994 1998)
ylabel(0 0.02 0.04 0.06 0.08)
xtitle(Year)
ytitle(Index (1986=0))
title("Within-Group Wage Inequality Decomposition (Sectors)", size(medlarge))
saving($graphs/sector-occupation/c-i-sector-alt,replace)
;

* Within-group occupations;

twoway (scatter iocond year , msymbol(i) c(l) lpattern(solid) lcolor(black) lwidth(thick))
(scatter iowithin year , msymbol(i) c(l) lpattern(solid) lcolor(red) lwidth(thick))
(scatter iobetween year , msymbol(i) c(l) lpattern(solid) lcolor(blue) lwidth(thick))
,
graphregion(fcolor(gs16))
legend(lab(1 "Overall") lab(2 "Within Occupation") lab(3 "Between Occupation"))
xlabel(1986 1990 1994 1998)
ylabel(0 0.02 0.04 0.06 0.08)
xtitle(Year)
ytitle(Index (1986=0))
title("Within-Group Wage Inequality Decomposition (Occupations)", size(medlarge))
saving($graphs/sector-occupation/c-i-occupation-alt,replace)
;

* Within-group sector-occupations;

twoway 
(scatter isocond year , msymbol(i) c(l) lpattern(solid) lcolor(green) lwidth(thick))
(scatter isowithin year , msymbol(i) c(l) lpattern(dash) lcolor(red) lwidth(thick))
(scatter isobetween year , msymbol(i) c(l) lpattern(solid) lcolor(blue) lwidth(medium))
,
graphregion(fcolor(gs16))
legend(lab(1 "Residual") lab(2 "Within Sector-Occupation") lab(3 "Between Sector-Occupation"))
xlabel(1986 1990 1994 1998)
ylabel(0 0.02 0.04 0.06 0.08 0.10 0.12)
xtitle(Year)
ytitle(Index (1986=0))
title("Panel B: Residual Inequality", size(medlarge))
saving($graphs/sector-occupation/c-i-sectoroccupation-alt,replace)
;

graph export $graphs/sector-occupation/c-i-sectoroccupation-alt.eps, as(eps) replace;

gr combine "$graphs/sector-occupation/c-i-rawobs.gph"
"$graphs/sector-occupation/c-i-sectoroccupation-alt.gph"
,
graphregion(fcolor(gs16))
iscale(0.4)
note(Note: Each series expressed as a difference from its 1986 value.)
saving($graphs/sector-occupation/total-obs-within-all,replace)
;

graph export $graphs/sector-occupation/total-obs-within-all.eps, as(eps) replace;

log close;
