
#delimit;

clear;
clear matrix;
set mem 8000m;
set matsize 10000;
set more off;
capture log close;

*******************************************************************;
**** This file undertakes the robustness test                  ****;
**** using more disaggregated industries for the decomposition ****;
**** of overall wage inequality into within and between        ****;
**** sector-occupation components in footnote 10 of the paper  ****;
*******************************************************************;

global dofiles="/home/sjredding/himr-restud/stata/dofiles";
global logs="/home/sjredding/himr-restud/stata/logs";
global input="/data/sjredding/himr-input";
global data="/data/sjredding/himr-restud";

log using $logs/sector-occupation/soanalysis_cnae.log, replace;

*******************************;
**** Read in and Save Data ****;
*******************************;

u $data/sector-occupation/withinbetween-1994-alt.dta, clear;
foreach yr of numlist 1995(1)1998 {;
append using $data/sector-occupation/withinbetween-`yr'-alt.dta;
};

lab var swithin "within sectors log wage component";
lab var sbetween "between sectors log wage component";
lab var stotal "total log wage component (across sectors)";

lab var owithin "within occupations log wage component";
lab var obetween "between occupations log wage component";
lab var ototal "total log wage component (across occupations)";

lab var sowithin "within sector-occupations log wage component";
lab var sobetween "between sector-occupations log wage component";
lab var sototal "total log wage component (across sector-occupations)";

order year swithin sbetween stotal owithin obetween ototal sowithin sobetween sototal;
sort year;
sa $data/sector-occupation/withinbetween-all-alt.dta, replace;

*************************;
**** Analyze Results ****;
*************************;

gen stest=swithin+sbetween;
replace stest=stest-stotal;
replace stest=int(stest*10000);

gen otest=owithin+obetween;
replace otest=otest-ototal;
replace otest=int(otest*10000);

gen sotest=sowithin+sobetween;
replace sotest=sotest-sototal;
replace sotest=int(sotest*10000);

su stest otest sotest;
drop stest otest sotest;

foreach var of varlist swithin sbetween stotal owithin obetween ototal sowithin sobetween sototal {;
gen temp=`var' if year==1994;
egen `var'94=max(temp);
drop temp;
gen i`var'=`var'-`var'94;
gen temp=`var' if year==1998;
egen `var'98=max(temp);
drop temp;
};   

**************************;
**** Tables for Paper ****;
**************************;

gen data=1;

gen sh_swithin=swithin/stotal;
gen sh_owithin=owithin/ototal;
gen sh_sowithin=sowithin/sototal;

foreach var of varlist swithin sbetween stotal owithin obetween ototal sowithin sobetween sototal {;
gen d_`var'=(`var'98-`var'94)/`var'94; 
};

gen wgt_swithin=swithin94/stotal94;
gen wgt_owithin=owithin94/ototal94;
gen wgt_sowithin=sowithin94/sototal94;

gen cnt_swithin=(wgt_swithin*d_swithin)/d_stotal;
gen cnt_owithin=(wgt_owithin*d_owithin)/d_ototal;
gen cnt_sowithin=(wgt_sowithin*d_sowithin)/d_sototal;

**** Table 1, Column (1), Row (6), within component level, sector-occupation 1994;

format sh_sowithin %10.3f;
table data if year==1994, c(mean sh_sowithin);

**** Footnote 10, within component changes, sector-occupation 1994-98

format cnt_sowithin %10.3f;
table data if year==1994, c(mean cnt_sowithin);

log close;
