
#delimit;

clear;
clear matrix;
set mem 8000m;
set matsize 10000;
set more off;
capture log close;

*********************************************************************;
**** This file undertakes the regional robustness                ****;
**** undertaking the decomposition of overall wage inequality    ****;
**** into within and between sector-occupation-region components ****;
**** in Table H2 of the online supplement (Columns (1) and (2))  ****; 
*********************************************************************;

global dofiles="/home/sjredding/himr-restud/stata/dofiles";
global logs="/home/sjredding/himr-restud/stata/logs";
global input="/data/sjredding/himr-input";
global data="/data/sjredding/himr-restud";

log using $logs/sector-occupation/soanalysis_sor.log, replace;

*******************************;
**** Read in and Save Data ****;
*******************************;

u $data/sector-occupation/sor-withinbetween-1986.dta, clear;
foreach yr of numlist 1987(1)1998 {;
append using $data/sector-occupation/sor-withinbetween-`yr'.dta;
};

lab var swithin 	"within sectors log wage component";
lab var sbetween 	"between sectors log wage component";
lab var stotal 		"total log wage component (across sectors)";

lab var owithin 	"within occupations log wage component";
lab var obetween 	"between occupations log wage component";
lab var ototal 		"total log wage component (across occupations)";

lab var sowithin 	"within sector-occupations log wage component";
lab var sobetween 	"between sector-occupations log wage component";
lab var sototal 	"total log wage component (across sector-occupations)";

lab var sorwithin 	"within sector-occupation-state log wage component";
lab var sorbetween 	"between sector-occupation-state log wage component";
lab var sortotal 	"total log wage component (for sector-occupation-states)";

lab var somwithin 	"within sector-occupation-meso log wage component";
lab var sombetween 	"between sector-occupation-meso log wage component";
lab var somtotal 	"total log wage component (for sector-occupation-mesos)";

lab var lwageyr9050	"Ratio 90:50 percentiles of log wages";
lab var lwageyr5010	"Ratio 50:10 percentiles of log wages";

lab var fswithin9050	"Ratio 90:50 percentiles of sector within component";
lab var fswithin5010	"Ratio 50:10 percentiles of sector within component";
lab var fsbetween9050	"Ratio 90:50 percentiles of sector between component";
lab var fsbetween5010	"Ratio 50:10 percentiles of sector between component";

lab var fowithin9050	"Ratio 90:50 percentiles of occupation within component";
lab var fowithin5010	"Ratio 50:10 percentiles of occupation within component";
lab var fobetween9050	"Ratio 90:50 percentiles of occupation between component";
lab var fobetween5010	"Ratio 50:10 percentiles of occupation between component";

lab var fsowithin9050	"Ratio 90:50 percentiles of sector-occupation within component";
lab var fsowithin5010	"Ratio 50:10 percentiles of sector-occupation within component";
lab var fsobetween9050	"Ratio 90:50 percentiles of sector-occupation between component";
lab var fsobetween5010	"Ratio 50:10 percentiles of sector-occupation between component";

local outvar="year swithin sbetween stotal owithin obetween ototal sowithin sobetween sototal";

order year swithin sbetween stotal owithin obetween ototal sowithin sobetween sototal
sorwithin sorbetween sortotal somwithin sombetween somtotal;
sort year;
sa $data/sector-occupation/sor-withinbetween-all.dta, replace;

*************************;
**** Analyze Results ****;
*************************;

gen stest=swithin+sbetween;
replace stest=stest-stotal;
replace stest=int(stest*10000);

gen otest=owithin+obetween;
replace otest=otest-ototal;
replace otest=int(otest*10000);

gen sotest=sowithin+sobetween;
replace sotest=sotest-sototal;
replace sotest=int(sotest*10000);

su stest otest sotest;
drop stest otest sotest;

local vars1="swithin sbetween stotal owithin obetween ototal sowithin sobetween sototal";
local vars2="sorwithin sorbetween sortotal somwithin sombetween somtotal";
local vars3="lwageyr9050 lwageyr5010";

foreach var of varlist `vars1' `vars2' `vars3' {;
gen temp=`var' if year==1986;
egen `var'86=max(temp);
drop temp;
gen i`var'=`var'-`var'86;
gen temp=`var' if year==1995;
egen `var'95=max(temp);
drop temp;
gen temp=`var' if year==1994;
egen `var'94=max(temp);
drop temp;
gen temp=`var' if year==1998;
egen `var'98=max(temp);
drop temp;
gen ii`var'=`var'98-`var'94;
};   

***********************************;
**** Baseline Tables for Paper ****;
***********************************;

gen data=1;

gen sh_swithin=swithin/stotal;
gen sh_owithin=owithin/ototal;
gen sh_sowithin=sowithin/sototal;
gen sh_sorwithin=sorwithin/sortotal;
gen sh_somwithin=somwithin/somtotal;

foreach var of varlist sh_swithin sh_owithin sh_sowithin sh_sorwithin sh_somwithin {;
gen temp=`var' if year==1986;
egen `var'86=max(temp);
drop temp;
gen temp=`var' if year==1994;
egen `var'94=max(temp);
drop temp;
};

foreach var of varlist swithin sbetween stotal owithin obetween ototal sowithin sobetween sototal sorwithin sorbetween sortotal somwithin sombetween somtotal {;
gen d_`var'86=(`var'95-`var'86)/`var'86;
gen d_`var'94=(`var'98-`var'94)/`var'94; 
};

gen cnt_swithin86=(sh_swithin86*d_swithin86)/d_stotal86;
gen cnt_owithin86=(sh_owithin86*d_owithin86)/d_ototal86;
gen cnt_sowithin86=(sh_sowithin86*d_sowithin86)/d_sototal86;
gen cnt_sorwithin86=(sh_sorwithin86*d_sorwithin86)/d_sortotal86;
gen cnt_somwithin86=(sh_somwithin86*d_somwithin86)/d_somtotal86;

gen cnt_swithin94=(sh_swithin94*d_swithin94)/d_stotal94;
gen cnt_owithin94=(sh_owithin94*d_owithin94)/d_ototal94;
gen cnt_sowithin94=(sh_sowithin94*d_sowithin94)/d_sototal94;
gen cnt_sorwithin94=(sh_sorwithin94*d_sorwithin94)/d_sortotal94;
gen cnt_somwithin94=(sh_somwithin94*d_somwithin94)/d_somtotal94;

**** Decomposition of level of overall wage inequality 1994;
**** within and between sector-occupation components;

**** Table H2, Column (1), Row (1);

format sh_sowithin %10.3f;
table data if year==1994, c(mean sh_sowithin);

**** Decomposition of changes in overall wage inequality 1986-95;
**** into within and between sector-occupation components;

**** Table H2, Column (2), Row (1);

format cnt_sowithin86 %10.3f;
table data if year==1995, c(mean cnt_sowithin86);

*********************************;
**** Robustness Tables       ****;
**** States and Meso region  ****;
*********************************;

**** Decomposition of level of overall wage inequality 1994;
**** within and between sector-occupation-state components;

**** Table H2, Column (1), Row (3);

format sh_sorwithin %10.3f;
table data if year==1994, c(mean sh_sorwithin);

**** Decomposition of level of overall wage inequality 1994;
**** within and between sector-occupation-meso components;

**** Table H2, Column (1), Row (4);

format sh_somwithin %10.3f;
table data if year==1994, c(mean sh_somwithin);

**** Decomposition of changes in overall wage inequality 1986-95;
**** into within and between sector-occupation-state components;

**** Table H2, Column (2), Row (3);

format cnt_sorwithin86 %10.3f;
table data if year==1995, c(mean cnt_sorwithin86);

**** Decomposition of changes in overall wage inequality 1986-95;
**** into within and between sector-occupation-meso components;

**** Table H2, Column (2), Row (4);

format cnt_somwithin86 %10.3f;
table data if year==1995, c(mean cnt_somwithin86);

log close;
