
#delimit;

clear;
clear matrix;
set mem 8000m;
set matsize 10000;
set more off;
capture log close;

*************************************************************************;
**** Robustness test decomposing overall wage inequality into within ****;
**** and between sector-occupation components including              ****;
**** agriculture and mining industries                               ****;
*************************************************************************;

global dofiles="/home/sjredding/himr-restud/stata/dofiles";
global logs="/home/sjredding/himr-restud/stata/logs";
global input="/data/sjredding/himr-input";
global data="/data/sjredding/himr-restud";

log using $logs/sector-occupation/soanova_agmining.log,replace;

******************************************;
* Loop to Undertake Analysis of Variance *;
******************************************;

foreach yr of numlist 1986(1)1998 {;

use $input/rais-secex-all-workers-`yr'.dta;

* Merge region information;

so cnpj_radic pis;
* Merge region data;
merge cnpj_radic using $data/geography/stateidentifiers-`yr'.dta;
tab _m;
keep if _m==3;
drop _m;

* Merge nationality information;
* nacionalidad;
* pis;
* ano;
* identificad;

so pis;
merge pis using $data/nationality/workers-template-`yr'-nacl-clean.dta;
tab _m;
drop _m;
so cnpj_radic pis;

* Define sample;

do $dofiles/routines/samplecond_agmining.do;

***************;
**** Setup ****;
***************;

* Demographics variables;
local demog="indchild indyouth indadol indnasc indearly indpeak indlate indretir indfem";

* Schooling variables;
local educ="indhigh indscoll indgrad";

* Basic occupation variables;
local occup="indprof indtech indwhit indsklb indunsklb";

xtile expqnt=temp_empr , nq(5);
tab expqnt,gen(tenure);

egen secoccup = group(firm_subsibge occup);
egen soo = group(firm_subsibge cbogrp);

***************************;
* Variance Decompositions *;
***************************;

* within/between decomposition for sectors;
areg lwageyr, abs(firm_subsibge);
predict fswithin if e(sample), res;
predict fsbetween if e(sample), xbd;
egen temp=sd(fsbetween);
gen sbetween = temp*temp;
drop temp;
egen temp=sd(fswithin);
gen swithin = temp*temp;
drop temp;
gen stotal = swithin + sbetween;

* within/between decomposition for occupations;
areg lwageyr, abs(occup);
predict fowithin if e(sample), res;
predict fobetween if e(sample), xbd;
egen temp=sd(fobetween);
gen obetween = temp*temp;
drop temp;
egen temp=sd(fowithin);
gen owithin = temp*temp;
drop temp;
gen ototal = owithin + obetween;

* Within/between decomposition for sector-occupations;
areg lwageyr, abs(secoccup);
predict fsowithin if e(sample), res;
predict fsobetween if e(sample), xbd;
egen temp=sd(fsobetween);
gen sobetween = temp*temp;
drop temp;
egen temp=sd(fsowithin);
gen sowithin = temp*temp;
drop temp;
gen sototal = sowithin + sobetween;

* Within/between decomposition for detailed occupations;
areg lwageyr, abs(cbogrp);
predict foowithin if e(sample), res;
predict foobetween if e(sample), xbd;
egen temp=sd(foobetween);
gen oobetween = temp*temp;
drop temp;
egen temp=sd(foowithin);
gen oowithin = temp*temp;
drop temp;
gen oototal = oowithin + oobetween;

* Within/between decomposition for sector-detailed-occupations;
areg lwageyr, abs(soo);
predict fsoowithin if e(sample), res;
predict fsoobetween if e(sample), xbd;
egen temp=sd(fsoobetween);
gen soobetween = temp*temp;
drop temp;
egen temp=sd(fsoowithin);
gen soowithin = temp*temp;
drop temp;
gen soototal = soowithin + soobetween;

****************;
* Polarization *;
****************;

foreach var of varlist lwageyr fswithin fsbetween fowithin fobetween fsowithin fsobetween {;
egen p90`var'=pctile(`var'), p(90);
egen p50`var'=pctile(`var'), p(50);
egen p10`var'=pctile(`var'), p(10);
gen `var'9050=p90`var'-p50`var';
gen `var'5010=p50`var'-p10`var';
};

*************;
* Save Data *;
*************;

collapse (mean) swithin sbetween stotal owithin obetween ototal sowithin sobetween sototal
oowithin oobetween oototal soowithin soobetween soototal
lwageyr9050 fswithin9050 fsbetween9050 fowithin9050 fobetween9050 fsowithin9050 fsobetween9050
lwageyr5010 fswithin5010 fsbetween5010 fowithin5010 fobetween5010 fsowithin5010 fsobetween5010, fast;

gen year=`yr';

sa $data/sector-occupation/withinbetween-agmining-`yr'.dta,replace;

};

log close;


