
#delimit;

clear;
clear matrix;
set mem 8000m;
set matsize 10000;
set more off;
capture log close;

************************************************************************;
**** This file constructs datasets to undertake the robustness test ****;
**** using more disaggregated industries for the decomposition      ****;
**** of overall wage inequality into within and between             ****;
**** sector-occupation components in footnote 10 of the paper       ****;
************************************************************************;

global dofiles="/home/sjredding/himr-restud/stata/dofiles";
global logs="/home/sjredding/himr-restud/stata/logs";
global input="/data/sjredding/himr-input";
global data="/data/sjredding/himr-restud";

log using $logs/sector-occupation/soanova_cnae.log,replace;

******************************************;
* Loop to Undertake Analysis of Variance *;
******************************************;

foreach yr of numlist 1994(1)1998 {;

use $input/rais-secex-all-workers-`yr'.dta;

* Drop observations with problematic firm_cnae codes;

drop if firm_cnae<=0;
drop if firm_cnae==.;

* Merge region information;

so cnpj_radic pis;
* Merge region data;
merge cnpj_radic using $data/geography/stateidentifiers-`yr'.dta;
tab _m;
keep if _m==3;
drop _m;

* Merge nationality information;
* nacionalidad;
* pis;
* ano;
* identificad;

so pis;
merge pis using $data/nationality/workers-template-`yr'-nacl-clean.dta;
tab _m;
drop _m;
so cnpj_radic pis;

* Define sample;

do $dofiles/routines/samplecond.do;

***************;
**** Setup ****;
***************;

* Demographics variables;
local demog="indchild indyouth indadol indnasc indearly indpeak indlate indretir indfem";

* Schooling variables;
local educ="indhigh indscoll indgrad";

* Basic occupation variables;
local occup="indprof indtech indwhit indsklb indunsklb";

xtile expqnt=temp_empr , nq(5);
tab expqnt,gen(tenure);

* categorical variables;

gen temp1=firm_cnae95;
tostring temp1,replace;
gen temp2=cbogrp;
tostring temp2, replace;
gen temp3=temp1+"AA"+temp2;
encode temp3, gen(secoccup);
drop temp1 temp2 temp3;

* Codebook;

codebook cbogrp;
codebook firm_cnae95;
codebook firm_subsibge;
codebook secoccup;

* within/between decomposition for sectors;
areg lwageyr, abs(firm_cnae95);
predict fwithin if e(sample), res;
predict fbetween if e(sample), xbd;
egen temp=sd(fbetween);
gen sbetween = temp*temp;
drop temp;
egen temp=sd(fwithin);
gen swithin = temp*temp;
drop temp;
drop fwithin;
drop fbetween;
gen stotal = swithin + sbetween;

* within/between decomposition for occupations;
areg lwageyr, abs(cbogrp);
predict fwithin if e(sample), res;
predict fbetween if e(sample), xbd;
egen temp=sd(fbetween);
gen obetween = temp*temp;
drop temp;
egen temp=sd(fwithin);
gen owithin = temp*temp;
drop temp;
drop fwithin;
drop fbetween;
gen ototal = owithin + obetween;

areg lwageyr, abs(secoccup);
predict fwithin if e(sample), res;
predict fbetween if e(sample), xbd;
egen temp=sd(fbetween);
gen sobetween = temp*temp;
drop temp;
egen temp=sd(fwithin);
gen sowithin = temp*temp;
drop temp;
drop fwithin;
drop fbetween;
gen sototal = sowithin + sobetween;

*************;
* Save Data *;
*************;

collapse (mean) swithin sbetween stotal owithin obetween ototal sowithin sobetween sototal, fast;
gen year=`yr';

sa $data/sector-occupation/withinbetween-`yr'-alt.dta,replace;

};

log close;


