
#delimit;

clear;
clear matrix;
set mem 4000m;
set matsize 10000;
set more off;
capture log close;
graph set print logo off;

global dofiles="/home/sjredding/himr-restud/stata/dofiles";
global logs="/home/sjredding/himr-restud/stata/logs";
global graphs="/home/sjredding/himr-restud/stata/graphs";
global input="/data/sjredding/himr-input";
global data="/data/sjredding/himr-restud";

************************************;
**** Clean up other export data ****;
************************************;

* IFS US GDP deflator;

clear;
insheet year usgdpdefl using "$input/aggdata/GDPdefl/US-GDP-defl-IFS.csv";

gen temp=usgdpdefl if year==1990;
egen usgdpdefl1990=max(temp);
drop temp;
replace usgdpdefl=usgdpdefl/usgdpdefl1990;

drop if year<1986;
drop if year>1998;
drop usgdpdefl1990;
so year;
sa $data/aggdata/GDPdefl/US-GDP-defl-IFS.dta, replace;

* NBER Export data;

u $input/wtf-brazil-aggtrade-subsibge-1986-2000.dta, clear;
drop if year<1986;
drop if year>1998;
drop if subs_ibge<2;
drop if subs_ibge>13;
ren subs_ibge firm_subsibge;
replace imports=imports*-1;
* Convert to dollars;
replace exports=exports*1000;
replace imports=imports*1000;
replace netexports=netexports*1000;
ren exports nberexports;
ren imports nberimports;
ren netexports nbernetexports; 

collapse (sum) nberexports nberimports nbernetexports, by(year);
so year;
sa $data/aggdata/exports/nber-exports.dta, replace;

*****************************;
**** Read in Mincer Data ****;
*****************************;

#delimit;
u $data/uncond/mincer/umincer-all-fun.dta , clear;

*****************************************;
**** Collapse to firm-industry level ****;
*****************************************;

collapse (sum) employ (mean) indexp indimp, by(cnpj_radic firm_subsibge year) fast;
gen lemploy=ln(employ);
so firm_subsibge year cnpj_radic;

***********************************************;
**** Number of Exporters and Non-exporters ****;
***********************************************;

egen noj_firm=count(cnpj_radic), by(firm_subsibge year);

egen temp=count(cnpj_radic) if indexp==1, by(firm_subsibge year);
egen noj_exp=max(temp), by(firm_subsibge year);
drop temp;
egen temp=count(cnpj_radic) if indexp==0, by(firm_subsibge year);
egen noj_nonexp=max(temp), by(firm_subsibge year);
drop temp;

egen temp=count(cnpj_radic) if indimp==1, by(firm_subsibge year);
egen noj_imp=max(temp), by(firm_subsibge year);
drop temp;
egen temp=count(cnpj_radic) if indimp==0, by(firm_subsibge year);
egen noj_nonimp=max(temp), by(firm_subsibge year);
drop temp;

egen temp=count(cnpj_radic) if indexp==1&indimp==1, by(firm_subsibge year);
egen noj_trade=max(temp), by(firm_subsibge year);
drop temp;
egen temp=count(cnpj_radic) if indexp==0&indimp==0, by(firm_subsibge year);
egen noj_nontrade=max(temp), by(firm_subsibge year);
drop temp;

***************************************************;
**** Employment of Exporters and Non-exporters ****;
**** Employment of Importers and Non-importers ****;
***************************************************;

egen emp_tot=sum(employ), by(firm_subsibge year);

egen temp=sum(employ) if indexp==1, by(firm_subsibge year);
egen emp_exp=max(temp), by(firm_subsibge year);
drop temp;

egen temp=sum(employ) if indexp==0, by(firm_subsibge year);
egen emp_nonexp=max(temp), by(firm_subsibge year);
drop temp;

egen temp=sum(employ) if indimp==1, by(firm_subsibge year);
egen emp_imp=max(temp), by(firm_subsibge year);
drop temp;

egen temp=sum(employ) if indimp==0, by(firm_subsibge year);
egen emp_nonimp=max(temp), by(firm_subsibge year);
drop temp;

egen temp=sum(employ) if indexp==1&indimp==1, by(firm_subsibge year);
egen emp_trade=max(temp), by(firm_subsibge year);
drop temp;

egen temp=sum(employ) if indexp==0&indimp==0, by(firm_subsibge year);
egen emp_nontrade=max(temp), by(firm_subsibge year);
drop temp;

************************************;
**** Collapse to Industry Level ****;
************************************;

local cvarlist="noj_firm noj_exp noj_nonexp noj_imp noj_nonimp noj_trade noj_nontrade 
emp_tot emp_exp emp_nonexp emp_imp emp_nonimp emp_trade emp_nontrade";

collapse (mean) `cvarlist' , by(firm_subsibge year) fast;
so firm_subsibge year;

*******************;
**** Save Data ****;
*******************;

so firm_subsibge year;
sa $data/uncond/exporter-all.dta, replace;

***********************************************;
*** Exporters share of firm and employment ****;
***********************************************;

#delimit;
u $data/uncond/exporter-all.dta, clear;

* Exporter shares;

gen exp_share=noj_exp/noj_firm;
gen exp_empshare=emp_exp/emp_tot;

gen imp_share=noj_imp/noj_firm;
gen imp_empshare=emp_imp/emp_tot;

* Agg shares;

egen tot_noj_exp=sum(noj_exp),by(year);
egen tot_noj_firm=sum(noj_firm),by(year);

egen tot_emp_exp=sum(emp_exp),by(year);
egen tot_emp_tot=sum(emp_tot),by(year);

gen tot_exp_share=tot_noj_exp/tot_noj_firm;
gen tot_exp_empshare=tot_emp_exp/tot_emp_tot;

**** Table A2 of the paper;
**** Industry table for 1994;
**** Columns (3) and (4);

* 1994;

table firm_subsibge if year==1994, c(mean exp_share mean exp_empshare);
 
* Aggregates 1994;

table firm_subsibge if year==1994, c(mean tot_exp_share mean tot_exp_empshare);

****************************;
**** Aggregate Analysis ****;
****************************;

#delimit;
u $data/uncond/exporter-all.dta, clear;
local cvarlist="noj_firm noj_exp noj_nonexp noj_imp noj_nonimp noj_trade noj_nontrade 
emp_tot emp_exp emp_nonexp emp_imp emp_nonimp emp_trade emp_nontrade";
collapse (sum) `cvarlist' , by(year) fast;
so year;
* Merge IFS GDP deflator;
merge year using $data/aggdata/GDPdefl/US-GDP-defl-IFS.dta;
tab _m;
drop _m;
so year;
* Merge NBER exports and importers;
merge year using $data/aggdata/exports/nber-exports.dta;
tab _m;
drop _m;
so year;

gen expempshare=emp_exp/emp_tot;
gen expshare=noj_exp/noj_firm;

gen impempshare=emp_imp/emp_tot;
gen impshare=noj_imp/noj_firm;

gen tradeempshare=emp_trade/emp_tot;
gen tradeshare=noj_trade/noj_firm;

gen nberexportsGDPdefl=nberexports/usgdpdefl;

lab var expshare "Share of Firms";
lab var expempshare "Share of Employment";

lab var impshare "Share of Firms";
lab var impempshare "Share of Employment";

lab var tradeshare "Share of Firms";
lab var tradeempshare "Share of Employment";

foreach var of varlist nberexportsGDPdefl {;
gen temp=`var' if year==1986;
egen `var'86=max(temp);
drop temp;
gen i`var'=`var'/`var'86;
};

**** Figure H1 in the online supplement;
**** Export participation;

twoway (scatter expshare year , msymbol(i) c(l) lpattern(solid) lcolor(blue) lwidth(thick) yaxis(1))
(scatter expempshare year , msymbol(i) c(l) lpattern(dash) lcolor(red) lwidth(thick) yaxis(2))
,
graphregion(fcolor(gs16))
legend(lab(1 "Share Exporters (left axis)") lab(2 "Exp Employ Share (right axis)") rows(2) cols(1) size(medium))
xlabel(1986 1990 1994 1998)
xtitle(Year)
saving($graphs/uncond/exppart-agg,replace)
;

graph export $graphs/uncond/exppart-agg.eps, as(eps) replace;

**** Figure H2 in the online supplement;
**** Real NBER manufacturing exports (GDP deflator);

twoway (scatter inberexportsGDPdefl year , msymbol(i) c(l) lpattern(solid) lcolor(red) lwidth(thick))
,
graphregion(fcolor(gs16))
legend(lab(1 "Real Total Manufacturing Exports (NBER)"))
ytitle("Index (1986=1)")
xlabel(1986 1990 1994 1998)
xtitle(Year)
saving($graphs/uncond/nberexportsGDPdefl,replace)
;

graph export $graphs/uncond/nberexportsGDPdefl.eps, as(eps) replace;

