
#delimit;

clear;
clear matrix;
set mem 4000m;
set matsize 10000;
set more off;
capture log close;

global dofiles="/home/sjredding/himr-restud/stata/dofiles";
global logs="/home/sjredding/himr-restud/stata/logs";
global input="/data/sjredding/himr-input";
global data="/data/sjredding/himr-restud";

**************************************;
* Unconditional Mincer Specification *;
**************************************;

foreach yr of numlist 1986(1)1998 {;

log using $logs/uncond/mincer/umincer-`yr'.log,replace;

use $input/rais-secex-all-workers-`yr'.dta, clear;

* Merge region information;

so cnpj_radic pis;
* Merge region data;
merge cnpj_radic using $data/geography/stateidentifiers-`yr'.dta;
tab _m;
keep if _m==3;
drop _m;

* Merge nationality information;
* nacionalidad;
* pis;
* ano;
* identificad;

so pis;
merge pis using $data/nationality/workers-template-`yr'-nacl-clean.dta;
tab _m;
drop _m;
so cnpj_radic pis;

* Define sample;

do $dofiles/routines/samplecond.do;

* Transform variables;

gen lfirm_emp=ln(firm_emp);
gen empbin=int(lfirm_emp*10);

tab empbin;

**************************;
* Wage Size Relationship *;
**************************;

* Demographics variables;
local demog="indchild indyouth indadol indnasc indearly indpeak indlate indretir indfem";

* Schooling variables;
local educ="indhigh indscoll indgrad";

* Basic occupation variables;
local occup="indprof indtech indwhit indsklb indunsklb";

xtile expqnt=temp_empr , nq(5);
tab expqnt,gen(tenure);

**************************;
* Baseline Specification *;
**************************;

gen reslwageyr=.;
gen obslwageyr=.;
gen felwageyr=.;

foreach sec of numlist 2(1)13 {;
display "Industry is";
display `sec';
foreach occ of numlist 1(1)5 {;
display "Occupation is";
display `occ';

* Mincer regressions;
areg lwageyr if firm_subsibge==`sec'&occup==`occ', robust abs(cnpj_radic);

* Residual wage inequality;
predict temp if e(sample), res;
replace reslwageyr=temp if firm_subsibge==`sec'&occup==`occ';
drop temp;
* Observables;
predict temp if e(sample), xb;
replace obslwageyr=temp if firm_subsibge==`sec'&occup==`occ';
drop temp;
* Time-varying firm fixed effects;
predict temp if e(sample), d;
replace felwageyr=temp if firm_subsibge==`sec'&occup==`occ';
drop temp; 

};
};

gen year=`yr';

******************;
* Save Firm Data *;
******************;

local mnvbles="lwageyr wageyr reslwageyr obslwageyr felwageyr firm_indexp";

collapse (mean) `mnvbles' (sum) employ , by(cnpj_radic firm_subsibge occup meso state year) fast;
order cnpj_radic firm_subsibge occup year lwageyr wageyr reslwageyr obslwageyr felwageyr firm_indexp employ meso state; 

gen lemploy=ln(employ);

lab var lwageyr 	"Firm mean of worker log wages";
lab var wageyr 		"Firm mean of worker wage";
lab var reslwageyr 	"Firm mean of worker residual log wage";
lab var obslwageyr 	"Firm mean of observable component worker log wage";
lab var felwageyr 	"Firm time-varying fixed effect";
lab var employ 		"Firm employment";
lab var firm_indexp 	"Indicator for whether a firm exports";
lab var lemploy 	"Log firm employment";

order cnpj_radic firm_subsibge occup year;
so cnpj_radic firm_subsibge occup year;
sa $data/uncond/mincer/umincer-`yr'.dta,replace;

log close;

};

*************************************;
**** Merge Mincer Files Together ****;
*************************************;

clear;
u $data/uncond/mincer/umincer-1986.dta;
foreach yr of numlist 1986(1)1998 {;
append using $data/uncond/mincer/umincer-`yr'.dta;
};
so cnpj_radic firm_subsibge occup year;
sa $data/uncond/mincer/umincer-all.dta, replace;

*****************************************;
**** Merge Mincer and Funcex by year ****;
*****************************************;

#delimit;
foreach yr of numlist 1986(1)1998 {;
clear;
u $data/uncond/mincer/umincer-`yr'.dta;
drop firm_indexp;
so cnpj_radic year occup;
merge cnpj_radic year using $data/funcex/expimp-cnpjradic-clean-`yr'.dta;
tab _m;
keep if _m==1|_m==3;
drop _m;
replace indexp=0 if indexp==.;
replace indimp=0 if indimp==.;
so cnpj_radic firm_subsibge occup year;
sa $data/uncond/mincer/umincer-`yr'-fun.dta, replace;
};

#delimit;
clear;
u $data/uncond/mincer/umincer-all.dta;
drop firm_indexp;
so cnpj_radic year occup;
merge cnpj_radic year using $data/funcex/expimp-cnpjradic-clean.dta;
tab _m;
keep if _m==1|_m==3;
drop _m;
replace indexp=0 if indexp==.;
replace indimp=0 if indimp==.;
egen max_indimp=max(indimp),by(year);
replace indimp=. if max_indimp==0;
drop max_indimp;
so cnpj_radic firm_subsibge occup year;
sa $data/uncond/mincer/umincer-all-fun.dta, replace;


